@@ -27,15 +27,16 @@ open Common
 (***************************************)
 
 let toplevel_env () =
-  List.rev (Safe_typing.structure_body_of_safe_env (Global.safe_env ()))
+  let mp, struc = Safe_typing.flatten_env (Global.safe_env ()) in
+  mp, List.rev struc
 
 let environment_until dir_opt =
   let rec parse = function
-    | [] when Option.is_empty dir_opt -> [Lib.current_mp (), toplevel_env ()]
+    | [] when Option.is_empty dir_opt -> [toplevel_env ()]
     | [] -> []
     | d :: l ->
       let meb =
-        Modops.destr_nofunctor (Global.lookup_module (MPfile d)).mod_type
+        Modops.destr_nofunctor (MPfile d) (Global.lookup_module (MPfile d)).mod_type
       in
       match dir_opt with
       | Some d' when DirPath.equal d d' -> [MPfile d, meb]
@@ -157,13 +158,16 @@ let factor_fix env sg l cb msb =
     (hack proposed by Elie)
 *)
 
-let expand_mexpr env mpo me =
+let expand_mexpr env mp me =
   let inl = Some (Flags.get_inline_level()) in
-  Mod_typing.translate_mse env mpo inl me
+  let state = ((Environ.universes env, Univ.Constraints.empty), Reductionops.inferred_universes) in
+  let mb, (_, cst) = Mod_typing.translate_module state env mp inl (MExpr ([], me, None)) in
+  mb.mod_type, mb.mod_delta
 
 let expand_modtype env mp me =
   let inl = Some (Flags.get_inline_level()) in
-  let mtb, _cst = Mod_typing.translate_modtype env mp inl ([],me) in
+  let state = ((Environ.universes env, Univ.Constraints.empty), Reductionops.inferred_universes) in
+  let mtb, _cst = Mod_typing.translate_modtype state env mp inl ([],me) in
   mtb
 
 let no_delta = Mod_subst.empty_delta_resolver
@@ -179,7 +183,7 @@ let flatten_modtype env mp me_alg struc_opt =
 *)
 
 let env_for_mtb_with_def env mp me reso idl =
-  let struc = Modops.destr_nofunctor me in
+  let struc = Modops.destr_nofunctor mp me in
   let l = Label.of_id (List.hd idl) in
   let spot = function (l',SFBconst _) -> Label.equal l l' | _ -> false in
   let before = fst (List.split_when spot struc) in
@@ -245,16 +249,16 @@ and extract_mexpr_spec env mp1 (me_struct_o,me_alg) = match me_alg with
      extract_msignature_spec env mp1 delta me_struct
 
 and extract_mexpression_spec env mp1 (me_struct,me_alg) = match me_alg with
-  | MoreFunctor (mbid, mtb, me_alg') ->
-      let me_struct' = match me_struct with
-        | MoreFunctor (mbid',_,me') when MBId.equal mbid' mbid -> me'
-        | _ -> assert false
+  | MEMoreFunctor me_alg' ->
+      let mbid, mtb, me_struct' = match me_struct with
+      | MoreFunctor (mbid, mtb, me') -> (mbid, mtb, me')
+      | _ -> assert false
       in
       let mp = MPbound mbid in
       let env' = Modops.add_module_type mp mtb env in
       MTfunsig (mbid, extract_mbody_spec env mp mtb,
                 extract_mexpression_spec env' mp1 (me_struct',me_alg'))
-  | NoFunctor m -> extract_mexpr_spec env mp1 (Some me_struct,m)
+  | MENoFunctor m -> extract_mexpr_spec env mp1 (Some me_struct,m)
 
 and extract_msignature_spec env mp1 reso = function
   | NoFunctor struc ->
@@ -332,7 +336,7 @@ and extract_mexpr env mp = function
       (* In Haskell/Scheme, we expand everything.
          For now, we also extract everything, dead code will be removed later
          (see [Modutil.optimize_struct]. *)
-      let sign,_,delta,_ = expand_mexpr env (Some mp) me in
+      let sign, delta = expand_mexpr env mp me in
       extract_msignature env mp delta ~all:true sign
   | MEident mp ->
       if is_modfile mp && not (modular ()) then error_MPfile_as_mod mp false;
@@ -341,15 +345,19 @@ and extract_mexpr env mp = function
       Miniml.MEapply (extract_mexpr env mp me,
                       extract_mexpr env mp (MEident arg))
 
-and extract_mexpression env mp = function
-  | NoFunctor me -> extract_mexpr env mp me
-  | MoreFunctor (mbid, mtb, me) ->
+and extract_mexpression env mp mty = function
+  | MENoFunctor me -> extract_mexpr env mp me
+  | MEMoreFunctor me ->
+      let (mbid, mtb, mty) = match mty with
+      | MoreFunctor (mbid, mtb, mty) -> (mbid, mtb, mty)
+      | NoFunctor _ -> assert false
+      in
       let mp1 = MPbound mbid in
       let env' = Modops.add_module_type mp1 mtb	env in
       Miniml.MEfunctor
         (mbid,
          extract_mbody_spec env mp1 mtb,
-         extract_mexpression env' mp me)
+         extract_mexpression env' mp mty me)
 
 and extract_msignature env mp reso ~all = function
   | NoFunctor struc ->
@@ -372,11 +380,12 @@ and extract_module env mp ~all mb =
      moment we don't support this situation. *)
   let impl = match mb.mod_expr with
     | Abstract -> error_no_module_expr mp
-    | Algebraic me -> extract_mexpression env mp me
+    | Algebraic me -> extract_mexpression env mp mb.mod_type me
     | Struct sign ->
       (* This module has a signature, otherwise it would be FullStruct.
          We extract just the elements required by this signature. *)
       let () = add_labels mp mb.mod_type in
+      let sign = Modops.annotate_struct_body sign mb.mod_type in
       extract_msignature env mp mb.mod_delta ~all:false sign
     | FullStruct -> extract_msignature env mp mb.mod_delta ~all mb.mod_type
   in
@@ -435,15 +444,23 @@ let mono_filename f =
             with UserError _ ->
               user_err Pp.(str "Extraction: provided filename is not a valid identifier")
         in
+        let f =
+          if Filename.is_relative f then
+            Filename.concat (output_directory ()) f
+          else f
+        in
         Some (f^d.file_suffix), Option.map ((^) f) d.sig_suffix, id
 
 (* Builds a suitable filename from a module id *)
 
 let module_filename mp =
   let f = file_of_modfile mp in
+  let id = Id.of_string f in
+  let f = Filename.concat (output_directory ()) f in
   let d = descr () in
-  let p = d.file_naming mp ^ d.file_suffix in
-  Some p, Option.map ((^) f) d.sig_suffix, Id.of_string f
+  let fimpl_base = d.file_naming mp ^ d.file_suffix in
+  let fimpl = Filename.concat (output_directory ()) fimpl_base in
+  Some fimpl, Option.map ((^) f) d.sig_suffix, id
 
 (*s Extraction of one decl to stdout. *)
 
@@ -557,7 +574,7 @@ let reset () =
   Visit.reset (); reset_tables (); reset_renaming_tables Everything
 
 let init ?(compute=false) ?(inner=false) modular library =
-  if not inner then (check_inside_section (); check_inside_module ());
+  if not inner then check_inside_section ();
   set_keywords (descr ()).keywords;
   set_modular modular;
   set_library library;
@@ -601,7 +618,8 @@ let full_extr f (refs,mps) =
   print_structure_to_file (mono_filename f) false struc;
   reset ()
 
-let full_extraction f lr = full_extr f (locate_ref lr)
+let full_extraction f lr =
+  full_extr f (locate_ref lr)
 
 (*s Separate extraction is similar to recursive extraction, with the output
    decomposed in many files, one per Coq .v file *)
@@ -610,11 +628,17 @@ let separate_extraction lr =
   init true false;
   let refs,mps = locate_ref lr in
   let struc = optimize_struct (refs,mps) (mono_environment refs mps) in
+  let () = List.iter (function
+    | MPfile _, _ -> ()
+    | (MPdot _ | MPbound _), _ ->
+      user_err (str "Separate Extraction from inside a module is not supported."))
+      struc
+  in
   warns ();
   let print = function
     | (MPfile dir as mp, sel) as e ->
         print_structure_to_file (module_filename mp) false [e]
-    | _ -> assert false
+    | (MPdot _ | MPbound _), _ -> assert false
   in
   List.iter print struc;
   reset ()
@@ -643,11 +667,11 @@ let simple_extraction r =
 (*s (Recursive) Extraction of a library. The vernacular command is
   \verb!(Recursive) Extraction Library! [M]. *)
 
-let extraction_library is_rec m =
+let extraction_library is_rec CAst.{loc;v=m} =
   init true true;
   let dir_m =
     let q = qualid_of_ident m in
-    try Nametab.full_name_module q with Not_found -> error_unknown_module q
+    try Nametab.full_name_module q with Not_found -> error_unknown_module ?loc q
   in
   Visit.add_mp_all (MPfile dir_m);
   let env = Global.env () in
@@ -699,7 +723,12 @@ let structure_for_compute env sg c =
 
 let compile f =
   try
-    let args = ["ocamlc";"-I";Filename.dirname f;"-c";f^"i";f] in
+    let args = [ "ocamlc"
+               ; "-package";"zarith"
+               ; "-I"; Filename.dirname f
+               ; "-c"; f^"i"
+               ; f
+               ] in
     let res = CUnix.sys_command (Envars.ocamlfind ()) args in
     match res with
     | Unix.WEXITED 0 -> ()
