@@ -6,8 +6,7 @@ open Pcoq.Prim
 
 
 
-let __coq_plugin_name = "extraction_plugin"
-let _ = Mltop.add_known_module __coq_plugin_name
+let _ = Mltop.add_known_module "coq-core.plugins.extraction"
 
 # 19 "plugins/extraction/g_extraction.mlg"
  
@@ -25,7 +24,7 @@ let pr_mlname _ _ _ s = spc () ++ qs s
 
 
 
-let (wit_mlname, mlname) = Tacentries.argument_extend ~name:"mlname" 
+let (wit_mlname, mlname) = Tacentries.argument_extend ~plugin:"coq-core.plugins.extraction" ~name:"mlname" 
                            {
                            Tacentries.arg_parsing = Vernacextend.Arg_rules (
                                                     [(Pcoq.Production.make
@@ -75,7 +74,7 @@ let pr_int_or_id _ _ _ = function
 
 
 
-let (wit_int_or_id, int_or_id) = Tacentries.argument_extend ~name:"int_or_id" 
+let (wit_int_or_id, int_or_id) = Tacentries.argument_extend ~plugin:"coq-core.plugins.extraction" ~name:"int_or_id" 
                                  {
                                  Tacentries.arg_parsing = Vernacextend.Arg_rules (
                                                           [(Pcoq.Production.make
@@ -126,13 +125,13 @@ let pr_language = function
 
 
 
-let (wit_language, language) = Vernacextend.vernac_argument_extend ~name:"language" 
+let (wit_language, language) = Vernacextend.vernac_argument_extend ~plugin:"coq-core.plugins.extraction" ~name:"language" 
                                {
                                Vernacextend.arg_parsing = Vernacextend.Arg_rules (
                                                           [(Pcoq.Production.make
                                                             (Pcoq.Rule.next 
                                                             (Pcoq.Rule.stop)
-                                                            ((Pcoq.Symbol.token (CLexer.terminal "JSON"))))
+                                                            ((Pcoq.Symbol.token (Pcoq.terminal "JSON"))))
                                                             (fun _ loc -> 
 # 70 "plugins/extraction/g_extraction.mlg"
                   JSON 
@@ -140,7 +139,7 @@ let (wit_language, language) = Vernacextend.vernac_argument_extend ~name:"langua
                                                           (Pcoq.Production.make
                                                            (Pcoq.Rule.next 
                                                            (Pcoq.Rule.stop)
-                                                           ((Pcoq.Symbol.token (CLexer.terminal "Scheme"))))
+                                                           ((Pcoq.Symbol.token (Pcoq.terminal "Scheme"))))
                                                            (fun _ loc -> 
 # 69 "plugins/extraction/g_extraction.mlg"
                     Scheme 
@@ -148,7 +147,7 @@ let (wit_language, language) = Vernacextend.vernac_argument_extend ~name:"langua
                                                           (Pcoq.Production.make
                                                            (Pcoq.Rule.next 
                                                            (Pcoq.Rule.stop)
-                                                           ((Pcoq.Symbol.token (CLexer.terminal "Haskell"))))
+                                                           ((Pcoq.Symbol.token (Pcoq.terminal "Haskell"))))
                                                            (fun _ loc -> 
 # 68 "plugins/extraction/g_extraction.mlg"
                      Haskell 
@@ -156,7 +155,7 @@ let (wit_language, language) = Vernacextend.vernac_argument_extend ~name:"langua
                                                           (Pcoq.Production.make
                                                            (Pcoq.Rule.next 
                                                            (Pcoq.Rule.stop)
-                                                           ((Pcoq.Symbol.token (CLexer.terminal "OCaml"))))
+                                                           ((Pcoq.Symbol.token (Pcoq.terminal "OCaml"))))
                                                            (fun _ loc -> 
 # 67 "plugins/extraction/g_extraction.mlg"
                    Ocaml 
@@ -169,11 +168,11 @@ let (wit_language, language) = Vernacextend.vernac_argument_extend ~name:"langua
                                }
 let _ = (wit_language, language)
 
-let () = Vernacextend.vernac_extend ~command:"Extraction" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.extraction") ~command:"Extraction" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Extraction", 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_global), 
                                      Vernacextend.TyNil)), (let coqpp_body x
-                                                           () = Vernacextend.VtDefault (fun () -> 
+                                                           () = Vernactypes.vtdefault (fun () -> 
                                                                 
 # 77 "plugins/extraction/g_extraction.mlg"
                                   simple_extraction x 
@@ -186,7 +185,7 @@ let () = Vernacextend.vernac_extend ~command:"Extraction" ~classifier:(fun _ ->
                                     Vernacextend.TyNonTerminal (Extend.TUlist1 (
                                                                 Extend.TUentry (Genarg.get_arg_tag wit_global)), 
                                     Vernacextend.TyNil))), (let coqpp_body l
-                                                           () = Vernacextend.VtDefault (fun () -> 
+                                                           () = Vernactypes.vtdefault (fun () -> 
                                                                 
 # 78 "plugins/extraction/g_extraction.mlg"
                                                       full_extraction None l 
@@ -200,7 +199,7 @@ let () = Vernacextend.vernac_extend ~command:"Extraction" ~classifier:(fun _ ->
                                                                 Extend.TUentry (Genarg.get_arg_tag wit_global)), 
                                     Vernacextend.TyNil))), (let coqpp_body f
                                                            l
-                                                           () = Vernacextend.VtDefault (fun () -> 
+                                                           () = Vernactypes.vtdefault (fun () -> 
                                                                 
 # 82 "plugins/extraction/g_extraction.mlg"
        full_extraction (Some f) l 
@@ -213,7 +212,7 @@ let () = Vernacextend.vernac_extend ~command:"Extraction" ~classifier:(fun _ ->
                                     Vernacextend.TyNonTerminal (Extend.TUlist1 (
                                                                 Extend.TUentry (Genarg.get_arg_tag wit_global)), 
                                     Vernacextend.TyNil))), (let coqpp_body l
-                                                           () = Vernacextend.VtDefault (fun () -> 
+                                                           () = Vernactypes.vtdefault (fun () -> 
                                                                 
 # 86 "plugins/extraction/g_extraction.mlg"
        extract_and_compile l 
@@ -222,13 +221,13 @@ let () = Vernacextend.vernac_extend ~command:"Extraction" ~classifier:(fun _ ->
                                                            -> coqpp_body l
                                                            (Attributes.unsupported_attributes atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"SeparateExtraction" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.extraction") ~command:"SeparateExtraction" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Separate", 
                                      Vernacextend.TyTerminal ("Extraction", 
                                      Vernacextend.TyNonTerminal (Extend.TUlist1 (
                                                                  Extend.TUentry (Genarg.get_arg_tag wit_global)), 
                                      Vernacextend.TyNil))), (let coqpp_body l
-                                                            () = Vernacextend.VtDefault (fun () -> 
+                                                            () = Vernactypes.vtdefault (fun () -> 
                                                                  
 # 92 "plugins/extraction/g_extraction.mlg"
        separate_extraction l 
@@ -237,12 +236,12 @@ let () = Vernacextend.vernac_extend ~command:"SeparateExtraction" ~classifier:(f
                                                             -> coqpp_body l
                                                             (Attributes.unsupported_attributes atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"ExtractionLibrary" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.extraction") ~command:"ExtractionLibrary" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Extraction", 
                                      Vernacextend.TyTerminal ("Library", 
-                                     Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_ident), 
+                                     Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_identref), 
                                      Vernacextend.TyNil))), (let coqpp_body m
-                                                            () = Vernacextend.VtDefault (fun () -> 
+                                                            () = Vernactypes.vtdefault (fun () -> 
                                                                  
 # 98 "plugins/extraction/g_extraction.mlg"
        extraction_library false m 
@@ -251,13 +250,13 @@ let () = Vernacextend.vernac_extend ~command:"ExtractionLibrary" ~classifier:(fu
                                                             -> coqpp_body m
                                                             (Attributes.unsupported_attributes atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"RecursiveExtractionLibrary" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.extraction") ~command:"RecursiveExtractionLibrary" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Recursive", 
                                      Vernacextend.TyTerminal ("Extraction", 
                                      Vernacextend.TyTerminal ("Library", 
-                                     Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_ident), 
+                                     Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_identref), 
                                      Vernacextend.TyNil)))), (let coqpp_body m
-                                                             () = Vernacextend.VtDefault (fun () -> 
+                                                             () = Vernactypes.vtdefault (fun () -> 
                                                                   
 # 103 "plugins/extraction/g_extraction.mlg"
        extraction_library true m 
@@ -266,12 +265,12 @@ let () = Vernacextend.vernac_extend ~command:"RecursiveExtractionLibrary" ~class
                                                              -> coqpp_body m
                                                              (Attributes.unsupported_attributes atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"ExtractionLanguage" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.extraction") ~command:"ExtractionLanguage" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Extraction", 
                                      Vernacextend.TyTerminal ("Language", 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_language), 
                                      Vernacextend.TyNil))), (let coqpp_body l
-                                                            () = Vernacextend.VtDefault (fun () -> 
+                                                            () = Vernactypes.vtdefault (fun () -> 
                                                                  
 # 109 "plugins/extraction/g_extraction.mlg"
        extraction_language l 
@@ -280,13 +279,13 @@ let () = Vernacextend.vernac_extend ~command:"ExtractionLanguage" ~classifier:(f
                                                             -> coqpp_body l
                                                             (Attributes.unsupported_attributes atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"ExtractionInline" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.extraction") ~command:"ExtractionInline" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Extraction", 
                                      Vernacextend.TyTerminal ("Inline", 
                                      Vernacextend.TyNonTerminal (Extend.TUlist1 (
                                                                  Extend.TUentry (Genarg.get_arg_tag wit_global)), 
                                      Vernacextend.TyNil))), (let coqpp_body l
-                                                            () = Vernacextend.VtDefault (fun () -> 
+                                                            () = Vernactypes.vtdefault (fun () -> 
                                                                  
 # 115 "plugins/extraction/g_extraction.mlg"
        extraction_inline true l 
@@ -295,13 +294,13 @@ let () = Vernacextend.vernac_extend ~command:"ExtractionInline" ~classifier:(fun
                                                             -> coqpp_body l
                                                             (Attributes.unsupported_attributes atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"ExtractionNoInline" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.extraction") ~command:"ExtractionNoInline" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Extraction", 
                                      Vernacextend.TyTerminal ("NoInline", 
                                      Vernacextend.TyNonTerminal (Extend.TUlist1 (
                                                                  Extend.TUentry (Genarg.get_arg_tag wit_global)), 
                                      Vernacextend.TyNil))), (let coqpp_body l
-                                                            () = Vernacextend.VtDefault (fun () -> 
+                                                            () = Vernactypes.vtdefault (fun () -> 
                                                                  
 # 120 "plugins/extraction/g_extraction.mlg"
        extraction_inline false l 
@@ -310,31 +309,31 @@ let () = Vernacextend.vernac_extend ~command:"ExtractionNoInline" ~classifier:(f
                                                             -> coqpp_body l
                                                             (Attributes.unsupported_attributes atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"PrintExtractionInline" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.extraction") ~command:"PrintExtractionInline" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Print", 
                                      Vernacextend.TyTerminal ("Extraction", 
                                      Vernacextend.TyTerminal ("Inline", 
                                      Vernacextend.TyNil))), (let coqpp_body () = 
-                                                            Vernacextend.VtDefault (fun () -> 
+                                                            Vernactypes.vtdefault (fun () -> 
                                                             
 # 125 "plugins/extraction/g_extraction.mlg"
       Feedback.msg_notice (print_extraction_inline ()) 
                                                             ) in fun ?loc ~atts ()
                                                             -> coqpp_body (Attributes.unsupported_attributes atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"ResetExtractionInline" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.extraction") ~command:"ResetExtractionInline" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Reset", 
                                      Vernacextend.TyTerminal ("Extraction", 
                                      Vernacextend.TyTerminal ("Inline", 
                                      Vernacextend.TyNil))), (let coqpp_body () = 
-                                                            Vernacextend.VtDefault (fun () -> 
+                                                            Vernactypes.vtdefault (fun () -> 
                                                             
 # 130 "plugins/extraction/g_extraction.mlg"
        reset_extraction_inline () 
                                                             ) in fun ?loc ~atts ()
                                                             -> coqpp_body (Attributes.unsupported_attributes atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"ExtractionImplicit" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.extraction") ~command:"ExtractionImplicit" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Extraction", 
                                      Vernacextend.TyTerminal ("Implicit", 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_global), 
@@ -343,21 +342,20 @@ let () = Vernacextend.vernac_extend ~command:"ExtractionImplicit" ~classifier:(f
                                                                    Extend.TUentry (Genarg.get_arg_tag wit_int_or_id)), 
                                                                    Vernacextend.TyTerminal ("]", 
                                                                    Vernacextend.TyNil)))))), 
-         (let coqpp_body r l
-         () = Vernacextend.VtDefault (fun () -> 
+         (let coqpp_body r l () = Vernactypes.vtdefault (fun () -> 
 # 136 "plugins/extraction/g_extraction.mlg"
        extraction_implicit r l 
-              ) in fun r
+                                  ) in fun r
          l ?loc ~atts () -> coqpp_body r l
          (Attributes.unsupported_attributes atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"ExtractionBlacklist" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.extraction") ~command:"ExtractionBlacklist" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Extraction", 
                                      Vernacextend.TyTerminal ("Blacklist", 
                                      Vernacextend.TyNonTerminal (Extend.TUlist1 (
-                                                                 Extend.TUentry (Genarg.get_arg_tag wit_ident)), 
+                                                                 Extend.TUentry (Genarg.get_arg_tag wit_preident)), 
                                      Vernacextend.TyNil))), (let coqpp_body l
-                                                            () = Vernacextend.VtDefault (fun () -> 
+                                                            () = Vernactypes.vtdefault (fun () -> 
                                                                  
 # 142 "plugins/extraction/g_extraction.mlg"
        extraction_blacklist l 
@@ -366,31 +364,31 @@ let () = Vernacextend.vernac_extend ~command:"ExtractionBlacklist" ~classifier:(
                                                             -> coqpp_body l
                                                             (Attributes.unsupported_attributes atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"PrintExtractionBlacklist" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.extraction") ~command:"PrintExtractionBlacklist" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Print", 
                                      Vernacextend.TyTerminal ("Extraction", 
                                      Vernacextend.TyTerminal ("Blacklist", 
                                      Vernacextend.TyNil))), (let coqpp_body () = 
-                                                            Vernacextend.VtDefault (fun () -> 
+                                                            Vernactypes.vtdefault (fun () -> 
                                                             
 # 147 "plugins/extraction/g_extraction.mlg"
        Feedback.msg_notice (print_extraction_blacklist ()) 
                                                             ) in fun ?loc ~atts ()
                                                             -> coqpp_body (Attributes.unsupported_attributes atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"ResetExtractionBlacklist" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.extraction") ~command:"ResetExtractionBlacklist" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Reset", 
                                      Vernacextend.TyTerminal ("Extraction", 
                                      Vernacextend.TyTerminal ("Blacklist", 
                                      Vernacextend.TyNil))), (let coqpp_body () = 
-                                                            Vernacextend.VtDefault (fun () -> 
+                                                            Vernactypes.vtdefault (fun () -> 
                                                             
 # 152 "plugins/extraction/g_extraction.mlg"
        reset_extraction_blacklist () 
                                                             ) in fun ?loc ~atts ()
                                                             -> coqpp_body (Attributes.unsupported_attributes atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"ExtractionConstant" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.extraction") ~command:"ExtractionConstant" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Extract", 
                                      Vernacextend.TyTerminal ("Constant", 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_global), 
@@ -400,14 +398,14 @@ let () = Vernacextend.vernac_extend ~command:"ExtractionConstant" ~classifier:(f
                                                                     Extend.TUentry (Genarg.get_arg_tag wit_mlname), 
                                                                     Vernacextend.TyNil)))))), 
          (let coqpp_body x idl y
-         () = Vernacextend.VtDefault (fun () -> 
+         () = Vernactypes.vtdefault (fun () -> 
 # 159 "plugins/extraction/g_extraction.mlg"
        extract_constant_inline false x idl y 
               ) in fun x
          idl y ?loc ~atts () -> coqpp_body x idl y
          (Attributes.unsupported_attributes atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"ExtractionInlinedConstant" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.extraction") ~command:"ExtractionInlinedConstant" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Extract", 
                                      Vernacextend.TyTerminal ("Inlined", 
                                      Vernacextend.TyTerminal ("Constant", 
@@ -415,15 +413,14 @@ let () = Vernacextend.vernac_extend ~command:"ExtractionInlinedConstant" ~classi
                                      Vernacextend.TyTerminal ("=>", Vernacextend.TyNonTerminal (
                                                                     Extend.TUentry (Genarg.get_arg_tag wit_mlname), 
                                                                     Vernacextend.TyNil)))))), 
-         (let coqpp_body x y
-         () = Vernacextend.VtDefault (fun () -> 
+         (let coqpp_body x y () = Vernactypes.vtdefault (fun () -> 
 # 164 "plugins/extraction/g_extraction.mlg"
        extract_constant_inline true x [] y 
-              ) in fun x
+                                  ) in fun x
          y ?loc ~atts () -> coqpp_body x y
          (Attributes.unsupported_attributes atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"ExtractionInductive" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.extraction") ~command:"ExtractionInductive" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Extract", 
                                      Vernacextend.TyTerminal ("Inductive", 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_global), 
@@ -439,21 +436,21 @@ let () = Vernacextend.vernac_extend ~command:"ExtractionInductive" ~classifier:(
                                                                     Extend.TUentry (Genarg.get_arg_tag wit_string)), 
                                                                     Vernacextend.TyNil))))))))), 
          (let coqpp_body x id idl o
-         () = Vernacextend.VtDefault (fun () -> 
+         () = Vernactypes.vtdefault (fun () -> 
 # 170 "plugins/extraction/g_extraction.mlg"
        extract_inductive x id idl o 
               ) in fun x
          id idl o ?loc ~atts () -> coqpp_body x id idl o
          (Attributes.unsupported_attributes atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"ShowExtraction" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.extraction") ~command:"ShowExtraction" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Show", 
                                      Vernacextend.TyTerminal ("Extraction", 
                                      Vernacextend.TyNil)), (let coqpp_body () = 
-                                                           Vernacextend.VtReadProof (
+                                                           Vernactypes.vtreadproof (fun ~pstate -> (
                                                            
 # 176 "plugins/extraction/g_extraction.mlg"
        show_extraction 
-                                                           ) in fun ?loc ~atts ()
+                                                           ) ~pstate) in fun ?loc ~atts ()
                                                            -> coqpp_body (Attributes.unsupported_attributes atts)), None))]
 
