@@ -1,5 +1,6 @@
+let _ = Mltop.add_known_module "coq-core.plugins.ltac"
 
-# 15 "plugins/ltac/g_obligations.mlg"
+# 17 "plugins/ltac/g_obligations.mlg"
  
 
 open Constrexpr
@@ -14,12 +15,13 @@ let (set_default_tactic, get_default_tactic, print_default_tactic) =
 let () =
   (* Delay to recover the tactic imperatively *)
   let tac = Proofview.tclBIND (Proofview.tclUNIT ()) begin fun () ->
-    snd (get_default_tactic ())
-  end in
+      get_default_tactic ()
+    end
+  in
   Declare.Obls.default_tactic := tac
 
 let with_tac f tac =
-  let env = Genintern.empty_glob_sign (Global.env ()) in
+  let env = Genintern.empty_glob_sign ~strict:true (Global.env ()) in
   let tac = match tac with
   | None -> None
   | Some tac ->
@@ -39,8 +41,6 @@ open Pcoq
 
 let sigref loc = mkRefC (Libnames.qualid_of_string ~loc "Coq.Init.Specif.sig")
 
-type 'a withtac_argtype = (Tacexpr.raw_tactic_expr option, 'a) Genarg.abstract_argument_type
-
 let wit_withtac : Tacexpr.raw_tactic_expr option Genarg.uniform_genarg_type =
   Genarg.create_arg "withtac"
 
@@ -50,12 +50,13 @@ let withtac = Pcoq.create_generic_entry2 "withtac" (Genarg.rawwit wit_withtac)
 
 let _ = let () = assert (Pcoq.Entry.is_empty withtac) in
         let () =
-        Pcoq.grammar_extend withtac
+        Egramml.grammar_extend ~plugin_uid:("coq-core.plugins.ltac", "g_obligations.mlg:0")
+        withtac
         (Pcoq.Fresh
         (Gramlib.Gramext.First, [(None, None,
                                  [Pcoq.Production.make (Pcoq.Rule.stop)
                                   (fun loc -> 
-# 68 "plugins/ltac/g_obligations.mlg"
+# 69 "plugins/ltac/g_obligations.mlg"
              None 
                                               );
                                  Pcoq.Production.make
@@ -63,11 +64,12 @@ let _ = let () = assert (Pcoq.Entry.is_empty withtac) in
                                                                  ((Pcoq.Symbol.token (Tok.PKEYWORD ("with")))))
                                                  ((Pcoq.Symbol.nterm Tactic.tactic)))
                                  (fun t _ loc -> 
-# 67 "plugins/ltac/g_obligations.mlg"
+# 68 "plugins/ltac/g_obligations.mlg"
                                        Some t 
                                                  )])]))
         in let () =
-        Pcoq.grammar_extend Constr.closed_binder
+        Egramml.grammar_extend ~plugin_uid:("coq-core.plugins.ltac", "g_obligations.mlg:1")
+        Constr.closed_binder
         (Pcoq.Reuse (None, [Pcoq.Production.make
                             (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.next 
                                                             (Pcoq.Rule.next 
@@ -83,7 +85,7 @@ let _ = let () = assert (Pcoq.Entry.is_empty withtac) in
                                                             ((Pcoq.Symbol.nterm Constr.lconstr)))
                                             ((Pcoq.Symbol.token (Tok.PKEYWORD (")")))))
                             (fun _ c _ t _ id _ loc -> 
-# 72 "plugins/ltac/g_obligations.mlg"
+# 73 "plugins/ltac/g_obligations.mlg"
                                                                                 
           let typ = mkAppC (sigref loc, [mkLambdaC ([id], default_binder_kind, t, c)]) in
           [CLocalAssum ([id], default_binder_kind, typ)] 
@@ -91,23 +93,23 @@ let _ = let () = assert (Pcoq.Entry.is_empty withtac) in
         in ()
 
 
-# 79 "plugins/ltac/g_obligations.mlg"
+# 80 "plugins/ltac/g_obligations.mlg"
  
 
 open Declare.Obls
 
 let obligation ~pm obl tac = with_tac (fun t -> obligation ~pm obl t) tac
-let next_obligation ~pm obl tac = with_tac (fun t -> next_obligation ~pm obl t) tac
+let next_obligation ~pm ?final obl tac = with_tac (fun t -> next_obligation ~pm ?final obl t) tac
 
 let classify_obbl _ = Vernacextend.(VtStartProof (Doesn'tGuaranteeOpacity,[]))
 
 
 
-let () = Vernacextend.vernac_extend ~command:"Obligations" ~classifier:( classify_obbl ) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.ltac") ~command:"Obligations" ~classifier:( classify_obbl ) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Obligation", 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_natural), 
                                      Vernacextend.TyTerminal ("of", Vernacextend.TyNonTerminal (
-                                                                    Extend.TUentry (Genarg.get_arg_tag wit_ident), 
+                                                                    Extend.TUentry (Genarg.get_arg_tag wit_identref), 
                                                                     Vernacextend.TyTerminal (":", 
                                                                     Vernacextend.TyNonTerminal (
                                                                     Extend.TUentry (Genarg.get_arg_tag wit_lglob), 
@@ -115,24 +117,24 @@ let () = Vernacextend.vernac_extend ~command:"Obligations" ~classifier:( classif
                                                                     Extend.TUentry (Genarg.get_arg_tag wit_withtac), 
                                                                     Vernacextend.TyNil))))))), 
          (let coqpp_body num name t tac
-         () = Vernacextend.VtDeclareProgram (
-# 92 "plugins/ltac/g_obligations.mlg"
-      obligation (num, Some name, Some t) tac 
-              ) in fun num
+         () = Vernactypes.vtdeclareprogram (fun ~pm -> (
+# 93 "plugins/ltac/g_obligations.mlg"
+      obligation (num, Some name.CAst.v, Some t) tac 
+              ) ~pm) in fun num
          name t tac ?loc ~atts () -> coqpp_body num name t tac
          (Attributes.unsupported_attributes atts)), None));
          (Vernacextend.TyML (false, Vernacextend.TyTerminal ("Obligation", 
                                     Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_natural), 
                                     Vernacextend.TyTerminal ("of", Vernacextend.TyNonTerminal (
-                                                                   Extend.TUentry (Genarg.get_arg_tag wit_ident), 
+                                                                   Extend.TUentry (Genarg.get_arg_tag wit_identref), 
                                                                    Vernacextend.TyNonTerminal (
                                                                    Extend.TUentry (Genarg.get_arg_tag wit_withtac), 
                                                                    Vernacextend.TyNil))))), 
          (let coqpp_body num name tac
-         () = Vernacextend.VtDeclareProgram (
-# 94 "plugins/ltac/g_obligations.mlg"
-      obligation (num, Some name, None) tac 
-              ) in fun num
+         () = Vernactypes.vtdeclareprogram (fun ~pm -> (
+# 95 "plugins/ltac/g_obligations.mlg"
+      obligation (num, Some name.CAst.v, None) tac 
+              ) ~pm) in fun num
          name tac ?loc ~atts () -> coqpp_body num name tac
          (Attributes.unsupported_attributes atts)), None));
          (Vernacextend.TyML (false, Vernacextend.TyTerminal ("Obligation", 
@@ -143,10 +145,10 @@ let () = Vernacextend.vernac_extend ~command:"Obligations" ~classifier:( classif
                                                                   Extend.TUentry (Genarg.get_arg_tag wit_withtac), 
                                                                   Vernacextend.TyNil))))), 
          (let coqpp_body num t tac
-         () = Vernacextend.VtDeclareProgram (
-# 96 "plugins/ltac/g_obligations.mlg"
+         () = Vernactypes.vtdeclareprogram (fun ~pm -> (
+# 97 "plugins/ltac/g_obligations.mlg"
       obligation (num, None, Some t) tac 
-              ) in fun num
+              ) ~pm) in fun num
          t tac ?loc ~atts () -> coqpp_body num t tac
          (Attributes.unsupported_attributes atts)), None));
          (Vernacextend.TyML (false, Vernacextend.TyTerminal ("Obligation", 
@@ -154,11 +156,11 @@ let () = Vernacextend.vernac_extend ~command:"Obligations" ~classifier:( classif
                                     Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_withtac), 
                                     Vernacextend.TyNil))), (let coqpp_body num
                                                            tac
-                                                           () = Vernacextend.VtDeclareProgram (
+                                                           () = Vernactypes.vtdeclareprogram (fun ~pm -> (
                                                                 
-# 98 "plugins/ltac/g_obligations.mlg"
+# 99 "plugins/ltac/g_obligations.mlg"
       obligation (num, None, None) tac 
-                                                                ) in fun num
+                                                                ) ~pm) in fun num
                                                            tac ?loc ~atts ()
                                                            -> coqpp_body num
                                                            tac
@@ -166,90 +168,82 @@ let () = Vernacextend.vernac_extend ~command:"Obligations" ~classifier:( classif
          (Vernacextend.TyML (false, Vernacextend.TyTerminal ("Next", 
                                     Vernacextend.TyTerminal ("Obligation", 
                                     Vernacextend.TyTerminal ("of", Vernacextend.TyNonTerminal (
-                                                                   Extend.TUentry (Genarg.get_arg_tag wit_ident), 
+                                                                   Extend.TUentry (Genarg.get_arg_tag wit_identref), 
                                                                    Vernacextend.TyNonTerminal (
                                                                    Extend.TUentry (Genarg.get_arg_tag wit_withtac), 
                                                                    Vernacextend.TyNil))))), 
          (let coqpp_body name tac
-         () = Vernacextend.VtDeclareProgram (
-# 100 "plugins/ltac/g_obligations.mlg"
-      next_obligation (Some name) tac 
-              ) in fun name
+         () = Vernactypes.vtdeclareprogram (fun ~pm -> (
+# 101 "plugins/ltac/g_obligations.mlg"
+      next_obligation (Some name.CAst.v) tac 
+              ) ~pm) in fun name
          tac ?loc ~atts () -> coqpp_body name tac
          (Attributes.unsupported_attributes atts)), None));
          (Vernacextend.TyML (false, Vernacextend.TyTerminal ("Next", 
                                     Vernacextend.TyTerminal ("Obligation", 
                                     Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_withtac), 
                                     Vernacextend.TyNil))), (let coqpp_body tac
-                                                           () = Vernacextend.VtDeclareProgram (
+                                                           () = Vernactypes.vtdeclareprogram (fun ~pm -> (
                                                                 
-# 101 "plugins/ltac/g_obligations.mlg"
+# 102 "plugins/ltac/g_obligations.mlg"
                                             next_obligation None tac 
-                                                                ) in fun tac
+                                                                ) ~pm) in fun tac
+                                                           ?loc ~atts ()
+                                                           -> coqpp_body tac
+                                                           (Attributes.unsupported_attributes atts)), None));
+         (Vernacextend.TyML (false, Vernacextend.TyTerminal ("Final", 
+                                    Vernacextend.TyTerminal ("Obligation", 
+                                    Vernacextend.TyTerminal ("of", Vernacextend.TyNonTerminal (
+                                                                   Extend.TUentry (Genarg.get_arg_tag wit_identref), 
+                                                                   Vernacextend.TyNonTerminal (
+                                                                   Extend.TUentry (Genarg.get_arg_tag wit_withtac), 
+                                                                   Vernacextend.TyNil))))), 
+         (let coqpp_body name tac
+         () = Vernactypes.vtdeclareprogram (fun ~pm -> (
+# 104 "plugins/ltac/g_obligations.mlg"
+      next_obligation ~final:true (Some name.CAst.v) tac 
+              ) ~pm) in fun name
+         tac ?loc ~atts () -> coqpp_body name tac
+         (Attributes.unsupported_attributes atts)), None));
+         (Vernacextend.TyML (false, Vernacextend.TyTerminal ("Final", 
+                                    Vernacextend.TyTerminal ("Obligation", 
+                                    Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_withtac), 
+                                    Vernacextend.TyNil))), (let coqpp_body tac
+                                                           () = Vernactypes.vtdeclareprogram (fun ~pm -> (
+                                                                
+# 105 "plugins/ltac/g_obligations.mlg"
+                                             next_obligation ~final:true None tac 
+                                                                ) ~pm) in fun tac
                                                            ?loc ~atts ()
                                                            -> coqpp_body tac
                                                            (Attributes.unsupported_attributes atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"Solve_Obligation" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
-         [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Solve", 
-                                     Vernacextend.TyTerminal ("Obligation", 
-                                     Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_natural), 
-                                     Vernacextend.TyTerminal ("of", Vernacextend.TyNonTerminal (
-                                                                    Extend.TUentry (Genarg.get_arg_tag wit_ident), 
-                                                                    Vernacextend.TyTerminal ("with", 
-                                                                    Vernacextend.TyNonTerminal (
-                                                                    Extend.TUentry (Genarg.get_arg_tag wit_tactic), 
-                                                                    Vernacextend.TyNil))))))), 
-         (let coqpp_body num name t
-         () = Vernacextend.VtModifyProgram (
-# 106 "plugins/ltac/g_obligations.mlg"
-      try_solve_obligation num (Some name) (Some (Tacinterp.interp t)) 
-              ) in fun num
-         name t ?loc ~atts () -> coqpp_body num name t
-         (Attributes.unsupported_attributes atts)), None));
-         (Vernacextend.TyML (false, Vernacextend.TyTerminal ("Solve", 
-                                    Vernacextend.TyTerminal ("Obligation", 
-                                    Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_natural), 
-                                    Vernacextend.TyTerminal ("with", 
-                                    Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_tactic), 
-                                    Vernacextend.TyNil))))), (let coqpp_body num
-                                                             t
-                                                             () = Vernacextend.VtModifyProgram (
-                                                                  
-# 108 "plugins/ltac/g_obligations.mlg"
-      try_solve_obligation num None (Some (Tacinterp.interp t)) 
-                                                                  ) in fun num
-                                                             t ?loc ~atts ()
-                                                             -> coqpp_body num
-                                                             t
-                                                             (Attributes.unsupported_attributes atts)), None))]
-
-let () = Vernacextend.vernac_extend ~command:"Solve_Obligations" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.ltac") ~command:"Solve_Obligations" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Solve", 
                                      Vernacextend.TyTerminal ("Obligations", 
                                      Vernacextend.TyTerminal ("of", Vernacextend.TyNonTerminal (
-                                                                    Extend.TUentry (Genarg.get_arg_tag wit_ident), 
+                                                                    Extend.TUentry (Genarg.get_arg_tag wit_identref), 
                                                                     Vernacextend.TyTerminal ("with", 
                                                                     Vernacextend.TyNonTerminal (
                                                                     Extend.TUentry (Genarg.get_arg_tag wit_tactic), 
                                                                     Vernacextend.TyNil)))))), 
          (let coqpp_body name t
-         () = Vernacextend.VtModifyProgram (
-# 113 "plugins/ltac/g_obligations.mlg"
-      try_solve_obligations (Some name) (Some (Tacinterp.interp t)) 
-              ) in fun name
+         () = Vernactypes.vtmodifyprogram (fun ~pm -> (
+# 110 "plugins/ltac/g_obligations.mlg"
+      try_solve_obligations (Some name.CAst.v) (Some (Tacinterp.interp t)) 
+              ) ~pm) in fun name
          t ?loc ~atts () -> coqpp_body name t
          (Attributes.unsupported_attributes atts)), None));
          (Vernacextend.TyML (false, Vernacextend.TyTerminal ("Solve", 
                                     Vernacextend.TyTerminal ("Obligations", 
                                     Vernacextend.TyTerminal ("of", Vernacextend.TyNonTerminal (
-                                                                   Extend.TUentry (Genarg.get_arg_tag wit_ident), 
+                                                                   Extend.TUentry (Genarg.get_arg_tag wit_identref), 
                                                                    Vernacextend.TyNil)))), 
          (let coqpp_body name
-         () = Vernacextend.VtModifyProgram (
-# 115 "plugins/ltac/g_obligations.mlg"
-      try_solve_obligations (Some name) None 
-              ) in fun name
+         () = Vernactypes.vtmodifyprogram (fun ~pm -> (
+# 112 "plugins/ltac/g_obligations.mlg"
+      try_solve_obligations (Some name.CAst.v) None 
+              ) ~pm) in fun name
          ?loc ~atts () -> coqpp_body name
          (Attributes.unsupported_attributes atts)), None));
          (Vernacextend.TyML (false, Vernacextend.TyTerminal ("Solve", 
@@ -257,152 +251,154 @@ let () = Vernacextend.vernac_extend ~command:"Solve_Obligations" ~classifier:(fu
                                     Vernacextend.TyTerminal ("with", 
                                     Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_tactic), 
                                     Vernacextend.TyNil)))), (let coqpp_body t
-                                                            () = Vernacextend.VtModifyProgram (
+                                                            () = Vernactypes.vtmodifyprogram (fun ~pm -> (
                                                                  
-# 117 "plugins/ltac/g_obligations.mlg"
+# 114 "plugins/ltac/g_obligations.mlg"
       try_solve_obligations None (Some (Tacinterp.interp t)) 
-                                                                 ) in fun t
+                                                                 ) ~pm) in fun t
                                                             ?loc ~atts ()
                                                             -> coqpp_body t
                                                             (Attributes.unsupported_attributes atts)), None));
          (Vernacextend.TyML (false, Vernacextend.TyTerminal ("Solve", 
                                     Vernacextend.TyTerminal ("Obligations", 
                                     Vernacextend.TyNil)), (let coqpp_body () = 
-                                                          Vernacextend.VtModifyProgram (
+                                                          Vernactypes.vtmodifyprogram (fun ~pm -> (
                                                           
-# 119 "plugins/ltac/g_obligations.mlg"
+# 116 "plugins/ltac/g_obligations.mlg"
       try_solve_obligations None None 
-                                                          ) in fun ?loc ~atts ()
+                                                          ) ~pm) in fun ?loc ~atts ()
                                                           -> coqpp_body (Attributes.unsupported_attributes atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"Solve_All_Obligations" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.ltac") ~command:"Solve_All_Obligations" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Solve", 
                                      Vernacextend.TyTerminal ("All", 
                                      Vernacextend.TyTerminal ("Obligations", 
                                      Vernacextend.TyTerminal ("with", 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_tactic), 
                                      Vernacextend.TyNil))))), (let coqpp_body t
-                                                              () = Vernacextend.VtModifyProgram (
+                                                              () = Vernactypes.vtmodifyprogram (fun ~pm -> (
                                                                    
-# 124 "plugins/ltac/g_obligations.mlg"
+# 121 "plugins/ltac/g_obligations.mlg"
       solve_all_obligations (Some (Tacinterp.interp t)) 
-                                                                   ) in fun t
+                                                                   ) ~pm) in fun t
                                                               ?loc ~atts ()
                                                               -> coqpp_body t
                                                               (Attributes.unsupported_attributes atts)), None));
          (Vernacextend.TyML (false, Vernacextend.TyTerminal ("Solve", 
                                     Vernacextend.TyTerminal ("All", Vernacextend.TyTerminal ("Obligations", 
                                                                     Vernacextend.TyNil))), 
-         (let coqpp_body () = Vernacextend.VtModifyProgram (
-# 126 "plugins/ltac/g_obligations.mlg"
+         (let coqpp_body () = Vernactypes.vtmodifyprogram (fun ~pm -> (
+# 123 "plugins/ltac/g_obligations.mlg"
       solve_all_obligations None 
-                              ) in fun ?loc ~atts ()
+                              ) ~pm) in fun ?loc ~atts ()
          -> coqpp_body (Attributes.unsupported_attributes atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"Admit_Obligations" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.ltac") ~command:"Admit_Obligations" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Admit", 
                                      Vernacextend.TyTerminal ("Obligations", 
                                      Vernacextend.TyTerminal ("of", Vernacextend.TyNonTerminal (
-                                                                    Extend.TUentry (Genarg.get_arg_tag wit_ident), 
+                                                                    Extend.TUentry (Genarg.get_arg_tag wit_identref), 
                                                                     Vernacextend.TyNil)))), 
          (let coqpp_body name
-         () = Vernacextend.VtModifyProgram (
-# 130 "plugins/ltac/g_obligations.mlg"
-                                                  admit_obligations (Some name) 
-              ) in fun name
+         () = Vernactypes.vtmodifyprogram (fun ~pm -> (
+# 127 "plugins/ltac/g_obligations.mlg"
+                                                     admit_obligations (Some name.CAst.v) 
+              ) ~pm) in fun name
          ?loc ~atts () -> coqpp_body name
          (Attributes.unsupported_attributes atts)), None));
          (Vernacextend.TyML (false, Vernacextend.TyTerminal ("Admit", 
                                     Vernacextend.TyTerminal ("Obligations", 
                                     Vernacextend.TyNil)), (let coqpp_body () = 
-                                                          Vernacextend.VtModifyProgram (
+                                                          Vernactypes.vtmodifyprogram (fun ~pm -> (
                                                           
-# 131 "plugins/ltac/g_obligations.mlg"
+# 128 "plugins/ltac/g_obligations.mlg"
                                  admit_obligations None 
-                                                          ) in fun ?loc ~atts ()
+                                                          ) ~pm) in fun ?loc ~atts ()
                                                           -> coqpp_body (Attributes.unsupported_attributes atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"Set_Solver" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.ltac") ~command:"Set_Solver" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Obligation", 
                                      Vernacextend.TyTerminal ("Tactic", 
                                      Vernacextend.TyTerminal (":=", Vernacextend.TyNonTerminal (
                                                                     Extend.TUentry (Genarg.get_arg_tag wit_tactic), 
                                                                     Vernacextend.TyNil)))), 
          (let coqpp_body t
-         locality = Vernacextend.VtDefault (fun () -> 
-# 135 "plugins/ltac/g_obligations.mlg"
-                                                                                    
+         locality = Vernactypes.vtdefault (fun () -> 
+# 132 "plugins/ltac/g_obligations.mlg"
+                                                                                                  
         set_default_tactic
-          (Locality.make_section_locality locality)
+          locality
           (Tacintern.glob_tactic t);
   
                     ) in fun t
          ?loc ~atts () -> coqpp_body t
-         (Attributes.parse Attributes.locality atts)), None))]
+         (Attributes.parse Tactic_option.tac_option_locality atts)), None))]
 
 
-# 142 "plugins/ltac/g_obligations.mlg"
+# 139 "plugins/ltac/g_obligations.mlg"
  
 
 open Pp
 
 
 
-let () = Vernacextend.vernac_extend ~command:"Show_Solver" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.ltac") ~command:"Show_Solver" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Show", 
                                      Vernacextend.TyTerminal ("Obligation", 
                                      Vernacextend.TyTerminal ("Tactic", 
                                      Vernacextend.TyNil))), (let coqpp_body () = 
-                                                            Vernacextend.VtDefault (fun () -> 
+                                                            Vernactypes.vtdefault (fun () -> 
                                                             
-# 149 "plugins/ltac/g_obligations.mlg"
+# 146 "plugins/ltac/g_obligations.mlg"
                                        
     Feedback.msg_notice (str"Program obligation tactic is " ++ print_default_tactic ()) 
                                                             ) in fun ?loc ~atts ()
                                                             -> coqpp_body (Attributes.unsupported_attributes atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"Show_Obligations" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.ltac") ~command:"Show_Obligations" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Obligations", 
                                      Vernacextend.TyTerminal ("of", Vernacextend.TyNonTerminal (
-                                                                    Extend.TUentry (Genarg.get_arg_tag wit_ident), 
+                                                                    Extend.TUentry (Genarg.get_arg_tag wit_identref), 
                                                                     Vernacextend.TyNil))), 
-         (let coqpp_body name () = Vernacextend.VtReadProgram (
-# 154 "plugins/ltac/g_obligations.mlg"
-                                          fun ~stack:_ -> show_obligations (Some name) 
-                                   ) in fun name
+         (let coqpp_body name
+         () = Vernactypes.vtreadprogram (fun ~pm -> (
+# 151 "plugins/ltac/g_obligations.mlg"
+                                             fun ~pm -> show_obligations ~pm (Some name.CAst.v) 
+              ) ~pm) in fun name
          ?loc ~atts () -> coqpp_body name
          (Attributes.unsupported_attributes atts)), None));
          (Vernacextend.TyML (false, Vernacextend.TyTerminal ("Obligations", 
                                     Vernacextend.TyNil), (let coqpp_body () = 
-                                                         Vernacextend.VtReadProgram (
+                                                         Vernactypes.vtreadprogram (fun ~pm -> (
                                                          
-# 155 "plugins/ltac/g_obligations.mlg"
-                         fun ~stack:_ -> show_obligations None 
-                                                         ) in fun ?loc ~atts ()
+# 152 "plugins/ltac/g_obligations.mlg"
+                         fun ~pm -> show_obligations ~pm None 
+                                                         ) ~pm) in fun ?loc ~atts ()
                                                          -> coqpp_body (Attributes.unsupported_attributes atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"Show_Preterm" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.ltac") ~command:"Show_Preterm" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Preterm", 
                                      Vernacextend.TyTerminal ("of", Vernacextend.TyNonTerminal (
-                                                                    Extend.TUentry (Genarg.get_arg_tag wit_ident), 
+                                                                    Extend.TUentry (Genarg.get_arg_tag wit_identref), 
                                                                     Vernacextend.TyNil))), 
-         (let coqpp_body name () = Vernacextend.VtReadProgram (
-# 159 "plugins/ltac/g_obligations.mlg"
-                                      fun ~stack:_ ~pm -> Feedback.msg_notice (show_term ~pm (Some name)) 
-                                   ) in fun name
+         (let coqpp_body name
+         () = Vernactypes.vtreadprogram (fun ~pm -> (
+# 156 "plugins/ltac/g_obligations.mlg"
+                                         fun ~pm -> Feedback.msg_notice (show_term ~pm (Some name.CAst.v)) 
+              ) ~pm) in fun name
          ?loc ~atts () -> coqpp_body name
          (Attributes.unsupported_attributes atts)), None));
          (Vernacextend.TyML (false, Vernacextend.TyTerminal ("Preterm", 
                                     Vernacextend.TyNil), (let coqpp_body () = 
-                                                         Vernacextend.VtReadProgram (
+                                                         Vernactypes.vtreadprogram (fun ~pm -> (
                                                          
-# 160 "plugins/ltac/g_obligations.mlg"
-                     fun ~stack:_ ~pm -> Feedback.msg_notice (show_term ~pm None) 
-                                                         ) in fun ?loc ~atts ()
+# 157 "plugins/ltac/g_obligations.mlg"
+                     fun ~pm -> Feedback.msg_notice (show_term ~pm None) 
+                                                         ) ~pm) in fun ?loc ~atts ()
                                                          -> coqpp_body (Attributes.unsupported_attributes atts)), None))]
 
 
-# 163 "plugins/ltac/g_obligations.mlg"
+# 160 "plugins/ltac/g_obligations.mlg"
  
 
 (* Declare a printer for the content of Program tactics *)
