@@ -1,5 +1,4 @@
-let __coq_plugin_name = "number_string_notation_plugin"
-let _ = Mltop.add_known_module __coq_plugin_name
+let _ = Mltop.add_known_module "coq-core.plugins.number_string_notation"
 
 # 13 "plugins/syntax/g_number_string.mlg"
  
@@ -8,7 +7,6 @@ open Notation
 open Number
 open String_notation
 open Pp
-open Names
 open Stdarg
 open Pcoq.Prim
 
@@ -17,13 +15,6 @@ let pr_number_after = function
   | Warning n -> str "warning after " ++ NumTok.UnsignedNat.print n
   | Abstract n -> str "abstract after " ++ NumTok.UnsignedNat.print n
 
-let pr_deprecated_number_modifier m = str "(" ++ pr_number_after m ++ str ")"
-
-let warn_deprecated_numeral_notation =
-  CWarnings.create ~name:"numeral-notation" ~category:"deprecated"
-    (fun () ->
-      strbrk "Numeral Notation is deprecated, please use Number Notation instead.")
-
 let pr_number_string_mapping (b, n, n') =
   if b then
     str "[" ++ Libnames.pr_qualid n ++ str "]" ++ spc () ++ str "=>" ++ spc ()
@@ -48,65 +39,7 @@ let pr_string_option l =
 
 
 
-let (wit_deprecated_number_modifier, deprecated_number_modifier) = Vernacextend.vernac_argument_extend ~name:"deprecated_number_modifier" 
-                                                                   {
-                                                                   Vernacextend.arg_parsing = 
-                                                                   Vernacextend.Arg_rules (
-                                                                   [(
-                                                                   Pcoq.Production.make
-                                                                   (Pcoq.Rule.next 
-                                                                   (Pcoq.Rule.next 
-                                                                   (Pcoq.Rule.next 
-                                                                   (Pcoq.Rule.next 
-                                                                   (Pcoq.Rule.next 
-                                                                   (Pcoq.Rule.stop)
-                                                                   ((Pcoq.Symbol.token (CLexer.terminal "("))))
-                                                                   ((Pcoq.Symbol.token (CLexer.terminal "abstract"))))
-                                                                   ((Pcoq.Symbol.token (CLexer.terminal "after"))))
-                                                                   ((Pcoq.Symbol.nterm bignat)))
-                                                                   ((Pcoq.Symbol.token (CLexer.terminal ")"))))
-                                                                   (fun _ n _
-                                                                   _ _ loc ->
-                                                                   
-# 63 "plugins/syntax/g_number_string.mlg"
-                                                Abstract (NumTok.UnsignedNat.of_string n) 
-                                                                   ));
-                                                                   (Pcoq.Production.make
-                                                                    (Pcoq.Rule.next 
-                                                                    (Pcoq.Rule.next 
-                                                                    (Pcoq.Rule.next 
-                                                                    (Pcoq.Rule.next 
-                                                                    (Pcoq.Rule.next 
-                                                                    (Pcoq.Rule.stop)
-                                                                    ((Pcoq.Symbol.token (CLexer.terminal "("))))
-                                                                    ((Pcoq.Symbol.token (CLexer.terminal "warning"))))
-                                                                    ((Pcoq.Symbol.token (CLexer.terminal "after"))))
-                                                                    ((Pcoq.Symbol.nterm bignat)))
-                                                                    ((Pcoq.Symbol.token (CLexer.terminal ")"))))
-                                                                    (fun _
-                                                                    waft _ _
-                                                                    _ loc ->
-                                                                    
-# 62 "plugins/syntax/g_number_string.mlg"
-                                                  Warning (NumTok.UnsignedNat.of_string waft) 
-                                                                    ));
-                                                                   (Pcoq.Production.make
-                                                                    (Pcoq.Rule.stop)
-                                                                    (fun
-                                                                    loc -> 
-                                                                    
-# 61 "plugins/syntax/g_number_string.mlg"
-           Nop 
-                                                                    ))]);
-                                                                   Vernacextend.arg_printer = fun env sigma -> 
-                                                                   
-# 60 "plugins/syntax/g_number_string.mlg"
-               pr_deprecated_number_modifier 
-                                                                   ;
-                                                                   }
-let _ = (wit_deprecated_number_modifier, deprecated_number_modifier)
-
-let (wit_number_string_mapping, number_string_mapping) = Vernacextend.vernac_argument_extend ~name:"number_string_mapping" 
+let (wit_number_string_mapping, number_string_mapping) = Vernacextend.vernac_argument_extend ~plugin:"coq-core.plugins.number_string_notation" ~name:"number_string_mapping" 
                                                          {
                                                          Vernacextend.arg_parsing = 
                                                          Vernacextend.Arg_rules (
@@ -117,14 +50,14 @@ let (wit_number_string_mapping, number_string_mapping) = Vernacextend.vernac_arg
                                                            (Pcoq.Rule.next 
                                                            (Pcoq.Rule.next 
                                                            (Pcoq.Rule.stop)
-                                                           ((Pcoq.Symbol.token (CLexer.terminal "["))))
+                                                           ((Pcoq.Symbol.token (Pcoq.terminal "["))))
                                                            ((Pcoq.Symbol.nterm reference)))
-                                                           ((Pcoq.Symbol.token (CLexer.terminal "]"))))
-                                                           ((Pcoq.Symbol.token (CLexer.terminal "=>"))))
+                                                           ((Pcoq.Symbol.token (Pcoq.terminal "]"))))
+                                                           ((Pcoq.Symbol.token (Pcoq.terminal "=>"))))
                                                            ((Pcoq.Symbol.nterm reference)))
                                                            (fun n' _ _ n _
                                                            loc -> 
-# 69 "plugins/syntax/g_number_string.mlg"
+# 54 "plugins/syntax/g_number_string.mlg"
                                                    true, n, n' 
                                                                   ));
                                                          (Pcoq.Production.make
@@ -133,22 +66,22 @@ let (wit_number_string_mapping, number_string_mapping) = Vernacextend.vernac_arg
                                                           (Pcoq.Rule.next 
                                                           (Pcoq.Rule.stop)
                                                           ((Pcoq.Symbol.nterm reference)))
-                                                          ((Pcoq.Symbol.token (CLexer.terminal "=>"))))
+                                                          ((Pcoq.Symbol.token (Pcoq.terminal "=>"))))
                                                           ((Pcoq.Symbol.nterm reference)))
                                                           (fun n' _ n loc ->
                                                           
-# 68 "plugins/syntax/g_number_string.mlg"
+# 53 "plugins/syntax/g_number_string.mlg"
                                            false, n, n' 
                                                           ))]);
                                                          Vernacextend.arg_printer = fun env sigma -> 
                                                          
-# 67 "plugins/syntax/g_number_string.mlg"
+# 52 "plugins/syntax/g_number_string.mlg"
                pr_number_string_mapping 
                                                          ;
                                                          }
 let _ = (wit_number_string_mapping, number_string_mapping)
 
-let (wit_number_string_via, number_string_via) = Vernacextend.vernac_argument_extend ~name:"number_string_via" 
+let (wit_number_string_via, number_string_via) = Vernacextend.vernac_argument_extend ~plugin:"coq-core.plugins.number_string_notation" ~name:"number_string_via" 
                                                  {
                                                  Vernacextend.arg_parsing = 
                                                  Vernacextend.Arg_rules (
@@ -159,25 +92,32 @@ let (wit_number_string_via, number_string_via) = Vernacextend.vernac_argument_ex
                                                                    (Pcoq.Rule.next 
                                                                    (Pcoq.Rule.next 
                                                                    (Pcoq.Rule.stop)
-                                                                   ((Pcoq.Symbol.token (CLexer.terminal "via"))))
+                                                                   ((Pcoq.Symbol.token (Pcoq.terminal "via"))))
                                                                    ((Pcoq.Symbol.nterm reference)))
-                                                                   ((Pcoq.Symbol.token (CLexer.terminal "mapping"))))
-                                                                   ((Pcoq.Symbol.token (CLexer.terminal "["))))
-                                                                   ((Pcoq.Symbol.list1sep ((Pcoq.Symbol.nterm number_string_mapping)) ((Pcoq.Symbol.token (CLexer.terminal ","))) false)))
-                                                                   ((Pcoq.Symbol.token (CLexer.terminal "]"))))
+                                                                   ((Pcoq.Symbol.token (Pcoq.terminal "mapping"))))
+                                                                   ((Pcoq.Symbol.token (Pcoq.terminal "["))))
+                                                                   ((Pcoq.Symbol.list1sep ((Pcoq.Symbol.nterm number_string_mapping)) ((Pcoq.Symbol.rules 
+                                                                   [Pcoq.Rules.make 
+                                                                   (Pcoq.Rule.next_norec 
+                                                                   (Pcoq.Rule.stop)
+                                                                   ((Pcoq.Symbol.token (Pcoq.terminal ","))))
+                                                                   (fun _
+                                                                   loc -> 
+                                                                   ())])) false)))
+                                                                   ((Pcoq.Symbol.token (Pcoq.terminal "]"))))
                                                    (fun _ l _ _ n _ loc -> 
-# 74 "plugins/syntax/g_number_string.mlg"
+# 59 "plugins/syntax/g_number_string.mlg"
                                                                                           n, l 
                                                                     ))]);
                                                  Vernacextend.arg_printer = fun env sigma -> 
                                                  
-# 73 "plugins/syntax/g_number_string.mlg"
+# 58 "plugins/syntax/g_number_string.mlg"
                pr_number_string_via 
                                                  ;
                                                  }
 let _ = (wit_number_string_via, number_string_via)
 
-let (wit_number_modifier, number_modifier) = Vernacextend.vernac_argument_extend ~name:"number_modifier" 
+let (wit_number_modifier, number_modifier) = Vernacextend.vernac_argument_extend ~plugin:"coq-core.plugins.number_string_notation" ~name:"number_modifier" 
                                              {
                                              Vernacextend.arg_parsing = 
                                              Vernacextend.Arg_rules (
@@ -185,40 +125,40 @@ let (wit_number_modifier, number_modifier) = Vernacextend.vernac_argument_extend
                                                (Pcoq.Rule.next (Pcoq.Rule.stop)
                                                                ((Pcoq.Symbol.nterm number_string_via)))
                                                (fun v loc -> 
-# 81 "plugins/syntax/g_number_string.mlg"
+# 66 "plugins/syntax/g_number_string.mlg"
                                 Via v 
                                                              ));
                                              (Pcoq.Production.make
                                               (Pcoq.Rule.next (Pcoq.Rule.next 
                                                               (Pcoq.Rule.next 
                                                               (Pcoq.Rule.stop)
-                                                              ((Pcoq.Symbol.token (CLexer.terminal "abstract"))))
-                                                              ((Pcoq.Symbol.token (CLexer.terminal "after"))))
+                                                              ((Pcoq.Symbol.token (Pcoq.terminal "abstract"))))
+                                                              ((Pcoq.Symbol.token (Pcoq.terminal "after"))))
                                                               ((Pcoq.Symbol.nterm bignat)))
                                               (fun n _ _ loc -> 
-# 80 "plugins/syntax/g_number_string.mlg"
+# 65 "plugins/syntax/g_number_string.mlg"
                                         After (Abstract (NumTok.UnsignedNat.of_string n)) 
                                                                 ));
                                              (Pcoq.Production.make
                                               (Pcoq.Rule.next (Pcoq.Rule.next 
                                                               (Pcoq.Rule.next 
                                                               (Pcoq.Rule.stop)
-                                                              ((Pcoq.Symbol.token (CLexer.terminal "warning"))))
-                                                              ((Pcoq.Symbol.token (CLexer.terminal "after"))))
+                                                              ((Pcoq.Symbol.token (Pcoq.terminal "warning"))))
+                                                              ((Pcoq.Symbol.token (Pcoq.terminal "after"))))
                                                               ((Pcoq.Symbol.nterm bignat)))
                                               (fun waft _ _ loc -> 
-# 79 "plugins/syntax/g_number_string.mlg"
+# 64 "plugins/syntax/g_number_string.mlg"
                                           After (Warning (NumTok.UnsignedNat.of_string waft)) 
                                                                    ))]);
                                              Vernacextend.arg_printer = fun env sigma -> 
                                              
-# 78 "plugins/syntax/g_number_string.mlg"
+# 63 "plugins/syntax/g_number_string.mlg"
                pr_number_modifier 
                                              ;
                                              }
 let _ = (wit_number_modifier, number_modifier)
 
-let (wit_number_options, number_options) = Vernacextend.vernac_argument_extend ~name:"number_options" 
+let (wit_number_options, number_options) = Vernacextend.vernac_argument_extend ~plugin:"coq-core.plugins.number_string_notation" ~name:"number_options" 
                                            {
                                            Vernacextend.arg_parsing = 
                                            Vernacextend.Arg_rules ([(
@@ -227,24 +167,31 @@ let (wit_number_options, number_options) = Vernacextend.vernac_argument_extend ~
                                                                    (Pcoq.Rule.next 
                                                                    (Pcoq.Rule.next 
                                                                    (Pcoq.Rule.stop)
-                                                                   ((Pcoq.Symbol.token (CLexer.terminal "("))))
-                                                                   ((Pcoq.Symbol.list1sep ((Pcoq.Symbol.nterm number_modifier)) ((Pcoq.Symbol.token (CLexer.terminal ","))) false)))
-                                                                   ((Pcoq.Symbol.token (CLexer.terminal ")"))))
+                                                                   ((Pcoq.Symbol.token (Pcoq.terminal "("))))
+                                                                   ((Pcoq.Symbol.list1sep ((Pcoq.Symbol.nterm number_modifier)) ((Pcoq.Symbol.rules 
+                                                                   [Pcoq.Rules.make 
+                                                                   (Pcoq.Rule.next_norec 
+                                                                   (Pcoq.Rule.stop)
+                                                                   ((Pcoq.Symbol.token (Pcoq.terminal ","))))
+                                                                   (fun _
+                                                                   loc -> 
+                                                                   ())])) false)))
+                                                                   ((Pcoq.Symbol.token (Pcoq.terminal ")"))))
                                                                    (fun _ l _
                                                                    loc -> 
                                                                    
-# 86 "plugins/syntax/g_number_string.mlg"
+# 71 "plugins/syntax/g_number_string.mlg"
                                                        l 
                                                                    ))]);
                                            Vernacextend.arg_printer = fun env sigma -> 
                                            
-# 85 "plugins/syntax/g_number_string.mlg"
+# 70 "plugins/syntax/g_number_string.mlg"
                pr_number_options 
                                            ;
                                            }
 let _ = (wit_number_options, number_options)
 
-let (wit_string_option, string_option) = Vernacextend.vernac_argument_extend ~name:"string_option" 
+let (wit_string_option, string_option) = Vernacextend.vernac_argument_extend ~plugin:"coq-core.plugins.number_string_notation" ~name:"string_option" 
                                          {
                                          Vernacextend.arg_parsing = Vernacextend.Arg_rules (
                                                                     [(
@@ -253,24 +200,24 @@ let (wit_string_option, string_option) = Vernacextend.vernac_argument_extend ~na
                                                                     (Pcoq.Rule.next 
                                                                     (Pcoq.Rule.next 
                                                                     (Pcoq.Rule.stop)
-                                                                    ((Pcoq.Symbol.token (CLexer.terminal "("))))
+                                                                    ((Pcoq.Symbol.token (Pcoq.terminal "("))))
                                                                     ((Pcoq.Symbol.nterm number_string_via)))
-                                                                    ((Pcoq.Symbol.token (CLexer.terminal ")"))))
+                                                                    ((Pcoq.Symbol.token (Pcoq.terminal ")"))))
                                                                     (fun _ v
                                                                     _ loc ->
                                                                     
-# 91 "plugins/syntax/g_number_string.mlg"
+# 76 "plugins/syntax/g_number_string.mlg"
                                         v 
                                                                     ))]);
                                          Vernacextend.arg_printer = fun env sigma -> 
                                          
-# 90 "plugins/syntax/g_number_string.mlg"
+# 75 "plugins/syntax/g_number_string.mlg"
                pr_string_option 
                                          ;
                                          }
 let _ = (wit_string_option, string_option)
 
-let () = Vernacextend.vernac_extend ~command:"NumberNotation" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.number_string_notation") ~command:"NumberNotation" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Number", 
                                      Vernacextend.TyTerminal ("Notation", 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_reference), 
@@ -279,35 +226,17 @@ let () = Vernacextend.vernac_extend ~command:"NumberNotation" ~classifier:(fun _
                                      Vernacextend.TyNonTerminal (Extend.TUopt (
                                                                  Extend.TUentry (Genarg.get_arg_tag wit_number_options)), 
                                      Vernacextend.TyTerminal (":", Vernacextend.TyNonTerminal (
-                                                                   Extend.TUentry (Genarg.get_arg_tag wit_ident), 
+                                                                   Extend.TUentry (Genarg.get_arg_tag wit_preident), 
                                                                    Vernacextend.TyNil)))))))), 
          (let coqpp_body ty f g nl sc
-         locality = Vernacextend.VtDefault (fun () -> 
-# 98 "plugins/syntax/g_number_string.mlg"
-      vernac_number_notation (Locality.make_module_locality locality) ty f g (Option.default [] nl) (Id.to_string sc) 
+         locality = Vernactypes.vtdefault (fun () -> 
+# 83 "plugins/syntax/g_number_string.mlg"
+      vernac_number_notation (Locality.make_module_locality locality) ty f g (Option.default [] nl) sc 
                     ) in fun ty
          f g nl sc ?loc ~atts () -> coqpp_body ty f g nl sc
-         (Attributes.parse Attributes.locality atts)), None));
-         (Vernacextend.TyML (false, Vernacextend.TyTerminal ("Numeral", 
-                                    Vernacextend.TyTerminal ("Notation", 
-                                    Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_reference), 
-                                    Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_reference), 
-                                    Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_reference), 
-                                    Vernacextend.TyTerminal (":", Vernacextend.TyNonTerminal (
-                                                                  Extend.TUentry (Genarg.get_arg_tag wit_ident), 
-                                                                  Vernacextend.TyNonTerminal (
-                                                                  Extend.TUentry (Genarg.get_arg_tag wit_deprecated_number_modifier), 
-                                                                  Vernacextend.TyNil)))))))), 
-         (let coqpp_body ty f g sc o
-         locality = Vernacextend.VtDefault (fun () -> 
-# 102 "plugins/syntax/g_number_string.mlg"
-      warn_deprecated_numeral_notation ();
-      vernac_number_notation (Locality.make_module_locality locality) ty f g [After o] (Id.to_string sc) 
-                    ) in fun ty
-         f g sc o ?loc ~atts () -> coqpp_body ty f g sc o
          (Attributes.parse Attributes.locality atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"StringNotation" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.number_string_notation") ~command:"StringNotation" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("String", 
                                      Vernacextend.TyTerminal ("Notation", 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_reference), 
@@ -316,12 +245,12 @@ let () = Vernacextend.vernac_extend ~command:"StringNotation" ~classifier:(fun _
                                      Vernacextend.TyNonTerminal (Extend.TUopt (
                                                                  Extend.TUentry (Genarg.get_arg_tag wit_string_option)), 
                                      Vernacextend.TyTerminal (":", Vernacextend.TyNonTerminal (
-                                                                   Extend.TUentry (Genarg.get_arg_tag wit_ident), 
+                                                                   Extend.TUentry (Genarg.get_arg_tag wit_preident), 
                                                                    Vernacextend.TyNil)))))))), 
          (let coqpp_body ty f g o sc
-         locality = Vernacextend.VtDefault (fun () -> 
-# 109 "plugins/syntax/g_number_string.mlg"
-      vernac_string_notation (Locality.make_module_locality locality) ty f g o (Id.to_string sc) 
+         locality = Vernactypes.vtdefault (fun () -> 
+# 89 "plugins/syntax/g_number_string.mlg"
+      vernac_string_notation (Locality.make_module_locality locality) ty f g o sc 
                     ) in fun ty
          f g o sc ?loc ~atts () -> coqpp_body ty f g o sc
          (Attributes.parse Attributes.locality atts)), None))]
