@@ -18,21 +18,21 @@ open Pp
 open Ppconstr
 open Printer
 open Util
-open Extraargs
 open Ssrprinters
 open Ssrcommon
 
 
 
-let __coq_plugin_name = "ssreflect_plugin"
-let _ = Mltop.add_known_module __coq_plugin_name
+let _ = Mltop.add_known_module "coq-core.plugins.ssreflect"
 
-# 39 "plugins/ssr/ssrvernac.mlg"
+# 38 "plugins/ssr/ssrvernac.mlg"
  
 
 (* Defining grammar rules with "xx" in it automatically declares keywords too,
  * we thus save the lexer to restore it at the end of the file *)
-let frozen_lexer = CLexer.get_keyword_state () ;;
+let frozen_lexer = ref (Pcoq.get_keyword_state ()) ;;
+let () = Mltop.add_init_function "coq-core.plugins.ssreflect" (fun () ->
+    frozen_lexer := Pcoq.get_keyword_state ())
 
 (* global syntactic changes and vernacular commands *)
 
@@ -84,7 +84,8 @@ let _ = let ssr_rtype = Pcoq.Entry.make "ssr_rtype"
         in
         let () = assert (Pcoq.Entry.is_empty ssr_rtype) in
         let () =
-        Pcoq.grammar_extend ssr_rtype
+        Egramml.grammar_extend ~plugin_uid:("coq-core.plugins.ssreflect", "ssrvernac.mlg:0")
+        ssr_rtype
         (Pcoq.Fresh
         (Gramlib.Gramext.First, [(None, None,
                                  [Pcoq.Production.make
@@ -92,31 +93,33 @@ let _ = let ssr_rtype = Pcoq.Entry.make "ssr_rtype"
                                                                   ((Pcoq.Symbol.token (Tok.PKEYWORD ("return")))))
                                                   ((Pcoq.Symbol.nterml term ("100"))))
                                   (fun t _ loc -> 
-# 88 "plugins/ssr/ssrvernac.mlg"
+# 89 "plugins/ssr/ssrvernac.mlg"
                                                     mk_rtype t 
                                                   )])]))
         in let () = assert (Pcoq.Entry.is_empty ssr_mpat) in
         let () =
-        Pcoq.grammar_extend ssr_mpat
+        Egramml.grammar_extend ~plugin_uid:("coq-core.plugins.ssreflect", "ssrvernac.mlg:1")
+        ssr_mpat
         (Pcoq.Fresh
         (Gramlib.Gramext.First, [(None, None,
                                  [Pcoq.Production.make
                                   (Pcoq.Rule.next (Pcoq.Rule.stop)
                                                   ((Pcoq.Symbol.nterm pattern)))
                                   (fun p loc -> 
-# 89 "plugins/ssr/ssrvernac.mlg"
+# 90 "plugins/ssr/ssrvernac.mlg"
                                 [[p]] 
                                                 )])]))
         in let () = assert (Pcoq.Entry.is_empty ssr_dpat) in
         let () =
-        Pcoq.grammar_extend ssr_dpat
+        Egramml.grammar_extend ~plugin_uid:("coq-core.plugins.ssreflect", "ssrvernac.mlg:2")
+        ssr_dpat
         (Pcoq.Fresh
         (Gramlib.Gramext.First, [(None, None,
                                  [Pcoq.Production.make
                                   (Pcoq.Rule.next (Pcoq.Rule.stop)
                                                   ((Pcoq.Symbol.nterm ssr_mpat)))
                                   (fun mp loc -> 
-# 93 "plugins/ssr/ssrvernac.mlg"
+# 94 "plugins/ssr/ssrvernac.mlg"
                          mp, no_ct, no_rt 
                                                  );
                                  Pcoq.Production.make
@@ -124,7 +127,7 @@ let _ = let ssr_rtype = Pcoq.Entry.make "ssr_rtype"
                                                                  ((Pcoq.Symbol.nterm ssr_mpat)))
                                                  ((Pcoq.Symbol.nterm ssr_rtype)))
                                  (fun rt mp loc -> 
-# 92 "plugins/ssr/ssrvernac.mlg"
+# 93 "plugins/ssr/ssrvernac.mlg"
                                          mp, mk_cnotype mp, rt 
                                                    );
                                  Pcoq.Production.make
@@ -136,12 +139,13 @@ let _ = let ssr_rtype = Pcoq.Entry.make "ssr_rtype"
                                                                  ((Pcoq.Symbol.nterm pattern)))
                                                  ((Pcoq.Symbol.nterm ssr_rtype)))
                                  (fun rt t _ mp loc -> 
-# 91 "plugins/ssr/ssrvernac.mlg"
+# 92 "plugins/ssr/ssrvernac.mlg"
                                                             mp, mk_ctype mp t, rt 
                                                        )])]))
         in let () = assert (Pcoq.Entry.is_empty ssr_dthen) in
         let () =
-        Pcoq.grammar_extend ssr_dthen
+        Egramml.grammar_extend ~plugin_uid:("coq-core.plugins.ssreflect", "ssrvernac.mlg:3")
+        ssr_dthen
         (Pcoq.Fresh
         (Gramlib.Gramext.First, [(None, None,
                                  [Pcoq.Production.make
@@ -151,24 +155,26 @@ let _ = let ssr_rtype = Pcoq.Entry.make "ssr_rtype"
                                                                   ((Pcoq.Symbol.token (Tok.PKEYWORD ("then")))))
                                                   ((Pcoq.Symbol.nterm lconstr)))
                                   (fun c _ dp loc -> 
-# 95 "plugins/ssr/ssrvernac.mlg"
+# 96 "plugins/ssr/ssrvernac.mlg"
                                                         mk_dthen ~loc dp c 
                                                      )])]))
         in let () = assert (Pcoq.Entry.is_empty ssr_elsepat) in
         let () =
-        Pcoq.grammar_extend ssr_elsepat
+        Egramml.grammar_extend ~plugin_uid:("coq-core.plugins.ssreflect", "ssrvernac.mlg:4")
+        ssr_elsepat
         (Pcoq.Fresh
         (Gramlib.Gramext.First, [(None, None,
                                  [Pcoq.Production.make
                                   (Pcoq.Rule.next (Pcoq.Rule.stop)
                                                   ((Pcoq.Symbol.token (Tok.PKEYWORD ("else")))))
                                   (fun _ loc -> 
-# 96 "plugins/ssr/ssrvernac.mlg"
+# 97 "plugins/ssr/ssrvernac.mlg"
                               [[CAst.make ~loc @@ CPatAtom None]] 
                                                 )])]))
         in let () = assert (Pcoq.Entry.is_empty ssr_else) in
         let () =
-        Pcoq.grammar_extend ssr_else
+        Egramml.grammar_extend ~plugin_uid:("coq-core.plugins.ssreflect", "ssrvernac.mlg:5")
+        ssr_else
         (Pcoq.Fresh
         (Gramlib.Gramext.First, [(None, None,
                                  [Pcoq.Production.make
@@ -176,11 +182,12 @@ let _ = let ssr_rtype = Pcoq.Entry.make "ssr_rtype"
                                                                   ((Pcoq.Symbol.nterm ssr_elsepat)))
                                                   ((Pcoq.Symbol.nterm lconstr)))
                                   (fun c mp loc -> 
-# 97 "plugins/ssr/ssrvernac.mlg"
+# 98 "plugins/ssr/ssrvernac.mlg"
                                                   CAst.make ~loc (mp, c) 
                                                    )])]))
         in let () =
-        Pcoq.grammar_extend binder_constr
+        Egramml.grammar_extend ~plugin_uid:("coq-core.plugins.ssreflect", "ssrvernac.mlg:6")
+        binder_constr
         (Pcoq.Reuse (None, [Pcoq.Production.make
                             (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.next 
                                                             (Pcoq.Rule.next 
@@ -202,7 +209,7 @@ let _ = let ssr_rtype = Pcoq.Entry.make "ssr_rtype"
                                                             ((Pcoq.Symbol.token (Tok.PKEYWORD ("in")))))
                                             ((Pcoq.Symbol.nterm lconstr)))
                             (fun c1 _ rt c _ t _ mp _ _ loc -> 
-# 115 "plugins/ssr/ssrvernac.mlg"
+# 116 "plugins/ssr/ssrvernac.mlg"
         mk_let ~loc rt [mk_pat c (mk_ctype mp t)] mp c1 
                                                                );
                            Pcoq.Production.make
@@ -222,7 +229,7 @@ let _ = let ssr_rtype = Pcoq.Entry.make "ssr_rtype"
                                                            ((Pcoq.Symbol.token (Tok.PKEYWORD ("in")))))
                                            ((Pcoq.Symbol.nterm lconstr)))
                            (fun c1 _ rt c _ mp _ _ loc -> 
-# 112 "plugins/ssr/ssrvernac.mlg"
+# 113 "plugins/ssr/ssrvernac.mlg"
         mk_let ~loc rt [mk_pat c (mk_cnotype mp)] mp c1 
                                                           );
                            Pcoq.Production.make
@@ -240,7 +247,7 @@ let _ = let ssr_rtype = Pcoq.Entry.make "ssr_rtype"
                                                            ((Pcoq.Symbol.token (Tok.PKEYWORD ("in")))))
                                            ((Pcoq.Symbol.nterm lconstr)))
                            (fun c1 _ c _ mp _ _ loc -> 
-# 109 "plugins/ssr/ssrvernac.mlg"
+# 110 "plugins/ssr/ssrvernac.mlg"
         mk_let ~loc no_rt [mk_pat c no_ct] mp c1 
                                                        );
                            Pcoq.Production.make
@@ -254,7 +261,7 @@ let _ = let ssr_rtype = Pcoq.Entry.make "ssr_rtype"
                                                            ((Pcoq.Symbol.nterm ssr_dthen)))
                                            ((Pcoq.Symbol.nterm ssr_else)))
                            (fun b2 db1 _ c _ loc -> 
-# 102 "plugins/ssr/ssrvernac.mlg"
+# 103 "plugins/ssr/ssrvernac.mlg"
         let b1, ct, rt = db1 in
       let b1, b2 = let open CAst in
         let {loc=l1; v=(p1, r1)}, {loc=l2; v=(p2, r2)} = b1, b2 in
@@ -273,13 +280,14 @@ let _ = let ssr_rtype = Pcoq.Entry.make "ssr_rtype"
                                                            ((Pcoq.Symbol.nterm ssr_dthen)))
                                            ((Pcoq.Symbol.nterm ssr_else)))
                            (fun b2 db1 _ c _ loc -> 
-# 100 "plugins/ssr/ssrvernac.mlg"
+# 101 "plugins/ssr/ssrvernac.mlg"
         let b1, ct, rt = db1 in CAst.make ~loc @@ CCases (MatchStyle, rt, [mk_pat c ct], [b1; b2]) 
                                                     )]))
         in ()
 
 let _ = let () =
-        Pcoq.grammar_extend closed_binder
+        Egramml.grammar_extend ~plugin_uid:("coq-core.plugins.ssreflect", "ssrvernac.mlg:7")
+        closed_binder
         (Pcoq.Reuse (None, [Pcoq.Production.make
                             (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.stop)
                                                             ((Pcoq.Symbol.rules 
@@ -289,7 +297,7 @@ let _ = let () =
                                                             ((Pcoq.Symbol.token (Tok.PKEYWORD ("&")))))
                                                             (fun _ loc -> 
                                                             
-# 122 "plugins/ssr/ssrvernac.mlg"
+# 123 "plugins/ssr/ssrvernac.mlg"
                                  () 
                                                             );
                                                             Pcoq.Rules.make 
@@ -298,24 +306,24 @@ let _ = let () =
                                                             ((Pcoq.Symbol.token (Tok.PKEYWORD ("of")))))
                                                             (fun _ loc -> 
                                                             
-# 122 "plugins/ssr/ssrvernac.mlg"
+# 123 "plugins/ssr/ssrvernac.mlg"
                  () 
                                                             )])))
                                             ((Pcoq.Symbol.nterml term ("99"))))
                             (fun c _ loc -> 
-# 123 "plugins/ssr/ssrvernac.mlg"
+# 124 "plugins/ssr/ssrvernac.mlg"
         [CLocalAssum ([CAst.make ~loc Anonymous], Default Explicit, c)] 
                                             )]))
         in ()
 
 
-# 141 "plugins/ssr/ssrvernac.mlg"
+# 142 "plugins/ssr/ssrvernac.mlg"
  
 
 let declare_one_prenex_implicit locality f =
   let fref =
     try Smartlocate.global_with_alias f
-    with _ -> errorstrm (pr_qualid f ++ str " is not declared") in
+    with e when CErrors.noncritical e -> errorstrm (pr_qualid f ++ str " is not declared") in
   let rec loop = function
   | a :: args' when Impargs.is_status_implicit a ->
     MaxImplicit :: loop args'
@@ -335,16 +343,16 @@ let declare_one_prenex_implicit locality f =
 
 
 
-let () = Vernacextend.vernac_extend ~command:"Ssrpreneximplicits" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.ssreflect") ~command:"Ssrpreneximplicits" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Prenex", 
                                      Vernacextend.TyTerminal ("Implicits", 
                                      Vernacextend.TyNonTerminal (Extend.TUlist1 (
                                                                  Extend.TUentry (Genarg.get_arg_tag wit_global)), 
                                      Vernacextend.TyNil))), (let coqpp_body fl
                                                             locality = 
-                                                            Vernacextend.VtDefault (fun () -> 
+                                                            Vernactypes.vtdefault (fun () -> 
                                                             
-# 168 "plugins/ssr/ssrvernac.mlg"
+# 169 "plugins/ssr/ssrvernac.mlg"
       
          let locality = Locality.make_section_locality locality in
          List.iter (declare_one_prenex_implicit locality) fl;
@@ -355,7 +363,8 @@ let () = Vernacextend.vernac_extend ~command:"Ssrpreneximplicits" ~classifier:(f
                                                             (Attributes.parse Attributes.locality atts)), None))]
 
 let _ = let () =
-        Pcoq.grammar_extend gallina_ext
+        Egramml.grammar_extend ~plugin_uid:("coq-core.plugins.ssreflect", "ssrvernac.mlg:8")
+        gallina_ext
         (Pcoq.Reuse (None, [Pcoq.Production.make
                             (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.next 
                                                             (Pcoq.Rule.stop)
@@ -366,20 +375,20 @@ let _ = let () =
                                             ((Pcoq.Symbol.token (Tok.PIDENT (Some
                                             ("Implicits"))))))
                             (fun _ _ _ loc -> 
-# 180 "plugins/ssr/ssrvernac.mlg"
-        Vernacexpr.VernacSetOption (false, ["Printing"; "Implicit"; "Defensive"], Vernacexpr.OptionUnset) 
+# 181 "plugins/ssr/ssrvernac.mlg"
+        Vernacexpr.VernacSynterp (Vernacexpr.VernacSetOption (false, ["Printing"; "Implicit"; "Defensive"], Vernacexpr.OptionUnset)) 
                                               )]))
         in ()
 
 
-# 193 "plugins/ssr/ssrvernac.mlg"
+# 194 "plugins/ssr/ssrvernac.mlg"
  
 
 let pr_raw_ssrhintref env sigma prc _ _ = let open CAst in function
-  | { v = CAppExpl ((None, r,x), args) } when isCHoles args ->
+  | { v = CAppExpl ((r,x), args) } when isCHoles args ->
     prc env sigma (CAst.make @@ CRef (r,x)) ++ str "|" ++ int (List.length args)
-  | { v = CApp ((_, { v = CRef _ }), _) } as c -> prc env sigma c
-  | { v = CApp ((_, c), args) } when isCxHoles args ->
+  | { v = CApp ({ v = CRef _ }, _) } as c -> prc env sigma c
+  | { v = CApp (c, args) } when isCxHoles args ->
     prc env sigma c ++ str "|" ++ int (List.length args)
   | c -> prc env sigma c
 
@@ -394,12 +403,12 @@ let pr_glob_ssrhintref env sigma _ _ _ (c, _) = pr_rawhintref env sigma c
 let pr_ssrhintref env sigma prc _ _ = prc env sigma
 
 let mkhintref ?loc c n = match c.CAst.v with
-  | CRef (r,x) -> CAst.make ?loc @@ CAppExpl ((None, r, x), mkCHoles ?loc n)
+  | CRef (r,x) -> CAst.make ?loc @@ CAppExpl ((r, x), mkCHoles ?loc n)
   | _ -> mkAppC (c, mkCHoles ?loc n)
 
 
 
-let (wit_ssrhintref, ssrhintref) = Tacentries.argument_extend ~name:"ssrhintref" 
+let (wit_ssrhintref, ssrhintref) = Tacentries.argument_extend ~plugin:"coq-core.plugins.ssreflect" ~name:"ssrhintref" 
                                    {
                                    Tacentries.arg_parsing = Vernacextend.Arg_rules (
                                                             [(Pcoq.Production.make
@@ -408,12 +417,12 @@ let (wit_ssrhintref, ssrhintref) = Tacentries.argument_extend ~name:"ssrhintref"
                                                               (Pcoq.Rule.next 
                                                               (Pcoq.Rule.stop)
                                                               ((Pcoq.Symbol.nterm constr)))
-                                                              ((Pcoq.Symbol.token (CLexer.terminal "|"))))
+                                                              ((Pcoq.Symbol.token (Pcoq.terminal "|"))))
                                                               ((Pcoq.Symbol.nterm natural)))
                                                               (fun n _ c
                                                               loc -> 
                                                               
-# 225 "plugins/ssr/ssrvernac.mlg"
+# 226 "plugins/ssr/ssrvernac.mlg"
                                        mkhintref ~loc c n  
                                                               ));
                                                             (Pcoq.Production.make
@@ -421,7 +430,7 @@ let (wit_ssrhintref, ssrhintref) = Tacentries.argument_extend ~name:"ssrhintref"
                                                              (Pcoq.Rule.stop)
                                                              ((Pcoq.Symbol.nterm constr)))
                                                              (fun c loc -> 
-# 224 "plugins/ssr/ssrvernac.mlg"
+# 225 "plugins/ssr/ssrvernac.mlg"
                         c  
                                                                     ))]);
                                    Tacentries.arg_tag = Some
@@ -431,22 +440,22 @@ let (wit_ssrhintref, ssrhintref) = Tacentries.argument_extend ~name:"ssrhintref"
                                    Tacentries.arg_interp = Tacentries.ArgInterpWit (wit_constr);
                                    Tacentries.arg_printer = ((fun env sigma -> 
                                                             
-# 222 "plugins/ssr/ssrvernac.mlg"
+# 223 "plugins/ssr/ssrvernac.mlg"
                    pr_raw_ssrhintref env sigma 
                                                             ), (fun env sigma -> 
                                                             
-# 223 "plugins/ssr/ssrvernac.mlg"
+# 224 "plugins/ssr/ssrvernac.mlg"
                     pr_glob_ssrhintref env sigma 
                                                             ), (fun env sigma -> 
                                                             
-# 221 "plugins/ssr/ssrvernac.mlg"
+# 222 "plugins/ssr/ssrvernac.mlg"
                pr_ssrhintref env sigma 
                                                             ));
                                    }
 let _ = (wit_ssrhintref, ssrhintref)
 
 
-# 228 "plugins/ssr/ssrvernac.mlg"
+# 229 "plugins/ssr/ssrvernac.mlg"
  
 
 (* View purpose *)
@@ -461,13 +470,13 @@ let pr_ssrviewpos _ _ _ = pr_viewpos
 
 
 
-let (wit_ssrviewpos, ssrviewpos) = Tacentries.argument_extend ~name:"ssrviewpos" 
+let (wit_ssrviewpos, ssrviewpos) = Tacentries.argument_extend ~plugin:"coq-core.plugins.ssreflect" ~name:"ssrviewpos" 
                                    {
                                    Tacentries.arg_parsing = Vernacextend.Arg_rules (
                                                             [(Pcoq.Production.make
                                                               (Pcoq.Rule.stop)
                                                               (fun loc -> 
-# 247 "plugins/ssr/ssrvernac.mlg"
+# 248 "plugins/ssr/ssrvernac.mlg"
               None  
                                                                     ));
                                                             (Pcoq.Production.make
@@ -475,12 +484,12 @@ let (wit_ssrviewpos, ssrviewpos) = Tacentries.argument_extend ~name:"ssrviewpos"
                                                              (Pcoq.Rule.next 
                                                              (Pcoq.Rule.next 
                                                              (Pcoq.Rule.stop)
-                                                             ((Pcoq.Symbol.token (CLexer.terminal "for"))))
-                                                             ((Pcoq.Symbol.token (CLexer.terminal "apply"))))
-                                                             ((Pcoq.Symbol.token (CLexer.terminal "//"))))
+                                                             ((Pcoq.Symbol.token (Pcoq.terminal "for"))))
+                                                             ((Pcoq.Symbol.token (Pcoq.terminal "apply"))))
+                                                             ((Pcoq.Symbol.token (Pcoq.terminal "//"))))
                                                              (fun _ _ _
                                                              loc -> 
-# 246 "plugins/ssr/ssrvernac.mlg"
+# 247 "plugins/ssr/ssrvernac.mlg"
                                  Some Ssrview.AdaptorDb.Equivalence  
                                                                     ));
                                                             (Pcoq.Production.make
@@ -489,13 +498,13 @@ let (wit_ssrviewpos, ssrviewpos) = Tacentries.argument_extend ~name:"ssrviewpos"
                                                              (Pcoq.Rule.next 
                                                              (Pcoq.Rule.next 
                                                              (Pcoq.Rule.stop)
-                                                             ((Pcoq.Symbol.token (CLexer.terminal "for"))))
-                                                             ((Pcoq.Symbol.token (CLexer.terminal "apply"))))
-                                                             ((Pcoq.Symbol.token (CLexer.terminal "/"))))
-                                                             ((Pcoq.Symbol.token (CLexer.terminal "/"))))
+                                                             ((Pcoq.Symbol.token (Pcoq.terminal "for"))))
+                                                             ((Pcoq.Symbol.token (Pcoq.terminal "apply"))))
+                                                             ((Pcoq.Symbol.token (Pcoq.terminal "/"))))
+                                                             ((Pcoq.Symbol.token (Pcoq.terminal "/"))))
                                                              (fun _ _ _ _
                                                              loc -> 
-# 245 "plugins/ssr/ssrvernac.mlg"
+# 246 "plugins/ssr/ssrvernac.mlg"
                                     Some Ssrview.AdaptorDb.Equivalence  
                                                                     ));
                                                             (Pcoq.Production.make
@@ -503,12 +512,12 @@ let (wit_ssrviewpos, ssrviewpos) = Tacentries.argument_extend ~name:"ssrviewpos"
                                                              (Pcoq.Rule.next 
                                                              (Pcoq.Rule.next 
                                                              (Pcoq.Rule.stop)
-                                                             ((Pcoq.Symbol.token (CLexer.terminal "for"))))
-                                                             ((Pcoq.Symbol.token (CLexer.terminal "apply"))))
-                                                             ((Pcoq.Symbol.token (CLexer.terminal "/"))))
+                                                             ((Pcoq.Symbol.token (Pcoq.terminal "for"))))
+                                                             ((Pcoq.Symbol.token (Pcoq.terminal "apply"))))
+                                                             ((Pcoq.Symbol.token (Pcoq.terminal "/"))))
                                                              (fun _ _ _
                                                              loc -> 
-# 244 "plugins/ssr/ssrvernac.mlg"
+# 245 "plugins/ssr/ssrvernac.mlg"
                                 Some Ssrview.AdaptorDb.Backward  
                                                                     ));
                                                             (Pcoq.Production.make
@@ -516,12 +525,12 @@ let (wit_ssrviewpos, ssrviewpos) = Tacentries.argument_extend ~name:"ssrviewpos"
                                                              (Pcoq.Rule.next 
                                                              (Pcoq.Rule.next 
                                                              (Pcoq.Rule.stop)
-                                                             ((Pcoq.Symbol.token (CLexer.terminal "for"))))
-                                                             ((Pcoq.Symbol.token (CLexer.terminal "move"))))
-                                                             ((Pcoq.Symbol.token (CLexer.terminal "/"))))
+                                                             ((Pcoq.Symbol.token (Pcoq.terminal "for"))))
+                                                             ((Pcoq.Symbol.token (Pcoq.terminal "move"))))
+                                                             ((Pcoq.Symbol.token (Pcoq.terminal "/"))))
                                                              (fun _ _ _
                                                              loc -> 
-# 243 "plugins/ssr/ssrvernac.mlg"
+# 244 "plugins/ssr/ssrvernac.mlg"
                                Some Ssrview.AdaptorDb.Forward  
                                                                     ))]);
                                    Tacentries.arg_tag = None;
@@ -530,29 +539,29 @@ let (wit_ssrviewpos, ssrviewpos) = Tacentries.argument_extend ~name:"ssrviewpos"
                                    Tacentries.arg_interp = Tacentries.ArgInterpRet;
                                    Tacentries.arg_printer = ((fun env sigma -> 
                                                             
-# 242 "plugins/ssr/ssrvernac.mlg"
+# 243 "plugins/ssr/ssrvernac.mlg"
                                         pr_ssrviewpos 
                                                             ), (fun env sigma -> 
                                                             
-# 242 "plugins/ssr/ssrvernac.mlg"
+# 243 "plugins/ssr/ssrvernac.mlg"
                                         pr_ssrviewpos 
                                                             ), (fun env sigma -> 
                                                             
-# 242 "plugins/ssr/ssrvernac.mlg"
+# 243 "plugins/ssr/ssrvernac.mlg"
                                         pr_ssrviewpos 
                                                             ));
                                    }
 let _ = (wit_ssrviewpos, ssrviewpos)
 
 
-# 250 "plugins/ssr/ssrvernac.mlg"
+# 251 "plugins/ssr/ssrvernac.mlg"
  
 
 let pr_ssrviewposspc _ _ _ i = pr_viewpos i ++ spc ()
 
 
 
-let (wit_ssrviewposspc, ssrviewposspc) = Tacentries.argument_extend ~name:"ssrviewposspc" 
+let (wit_ssrviewposspc, ssrviewposspc) = Tacentries.argument_extend ~plugin:"coq-core.plugins.ssreflect" ~name:"ssrviewposspc" 
                                          {
                                          Tacentries.arg_parsing = Vernacextend.Arg_alias (ssrviewpos);
                                          Tacentries.arg_tag = Some
@@ -562,22 +571,22 @@ let (wit_ssrviewposspc, ssrviewposspc) = Tacentries.argument_extend ~name:"ssrvi
                                          Tacentries.arg_interp = Tacentries.ArgInterpWit (wit_ssrviewpos);
                                          Tacentries.arg_printer = ((fun env sigma -> 
                                                                   
-# 256 "plugins/ssr/ssrvernac.mlg"
+# 257 "plugins/ssr/ssrvernac.mlg"
                                                                pr_ssrviewposspc 
                                                                   ), (fun env sigma -> 
                                                                   
-# 256 "plugins/ssr/ssrvernac.mlg"
+# 257 "plugins/ssr/ssrvernac.mlg"
                                                                pr_ssrviewposspc 
                                                                   ), (fun env sigma -> 
                                                                   
-# 256 "plugins/ssr/ssrvernac.mlg"
+# 257 "plugins/ssr/ssrvernac.mlg"
                                                                pr_ssrviewposspc 
                                                                   ));
                                          }
 let _ = (wit_ssrviewposspc, ssrviewposspc)
 
 
-# 260 "plugins/ssr/ssrvernac.mlg"
+# 261 "plugins/ssr/ssrvernac.mlg"
  
 
 let print_view_hints env sigma kind l =
@@ -587,15 +596,15 @@ let print_view_hints env sigma kind l =
 
 
 
-let () = Vernacextend.vernac_extend ~command:"PrintView" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.ssreflect") ~command:"PrintView" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Print", 
                                      Vernacextend.TyTerminal ("Hint", 
                                      Vernacextend.TyTerminal ("View", 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_ssrviewpos), 
                                      Vernacextend.TyNil)))), (let coqpp_body i
-                                                             () = Vernacextend.VtDefault (fun () -> 
+                                                             () = Vernactypes.vtdefault (fun () -> 
                                                                   
-# 271 "plugins/ssr/ssrvernac.mlg"
+# 272 "plugins/ssr/ssrvernac.mlg"
    
     let env = Global.env () in
     let sigma = Evd.from_env env in
@@ -614,7 +623,7 @@ let () = Vernacextend.vernac_extend ~command:"PrintView" ~classifier:(fun _ -> V
                                                              (Attributes.unsupported_attributes atts)), None))]
 
 
-# 285 "plugins/ssr/ssrvernac.mlg"
+# 286 "plugins/ssr/ssrvernac.mlg"
  
 
 let glob_view_hints lvh =
@@ -622,7 +631,7 @@ let glob_view_hints lvh =
 
 
 
-let () = Vernacextend.vernac_extend ~command:"HintView" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.ssreflect") ~command:"HintView" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Hint", 
                                      Vernacextend.TyTerminal ("View", 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_ssrviewposspc), 
@@ -630,9 +639,9 @@ let () = Vernacextend.vernac_extend ~command:"HintView" ~classifier:(fun _ -> Ve
                                                                  Extend.TUentry (Genarg.get_arg_tag wit_ssrhintref)), 
                                      Vernacextend.TyNil)))), (let coqpp_body n
                                                              lvh
-                                                             () = Vernacextend.VtDefault (fun () -> 
+                                                             () = Vernactypes.vtdefault (fun () -> 
                                                                   
-# 294 "plugins/ssr/ssrvernac.mlg"
+# 295 "plugins/ssr/ssrvernac.mlg"
        let hints = glob_view_hints lvh in
        match n with
        | None ->
@@ -648,14 +657,15 @@ let () = Vernacextend.vernac_extend ~command:"HintView" ~classifier:(fun _ -> Ve
                                                              (Attributes.unsupported_attributes atts)), None))]
 
 
-# 305 "plugins/ssr/ssrvernac.mlg"
+# 306 "plugins/ssr/ssrvernac.mlg"
  
 
 open G_vernac
 
 
 let _ = let () =
-        Pcoq.grammar_extend query_command
+        Egramml.grammar_extend ~plugin_uid:("coq-core.plugins.ssreflect", "ssrvernac.mlg:9")
+        query_command
         (Pcoq.Reuse (None, [Pcoq.Production.make
                             (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.next 
                                                             (Pcoq.Rule.next 
@@ -666,7 +676,7 @@ let _ = let () =
                                                             ((Pcoq.Symbol.nterm search_queries)))
                                             ((Pcoq.Symbol.token (Tok.PKEYWORD (".")))))
                             (fun _ l s _ loc -> 
-# 315 "plugins/ssr/ssrvernac.mlg"
+# 316 "plugins/ssr/ssrvernac.mlg"
             let (sl,m) = l in
             fun g ->
               Vernacexpr.VernacSearch (Vernacexpr.Search (s::sl),g, m) 
@@ -674,7 +684,7 @@ let _ = let () =
         in ()
 
 
-# 336 "plugins/ssr/ssrvernac.mlg"
+# 337 "plugins/ssr/ssrvernac.mlg"
  
 
 open Pltac
@@ -682,7 +692,8 @@ open Pltac
 
 
 let _ = let () =
-        Pcoq.grammar_extend hypident
+        Egramml.grammar_extend ~plugin_uid:("coq-core.plugins.ssreflect", "ssrvernac.mlg:10")
+        hypident
         (Pcoq.Reuse (None, [Pcoq.Production.make
                             (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.next 
                                                             (Pcoq.Rule.next 
@@ -695,7 +706,7 @@ let _ = let () =
                                                             ((Pcoq.Symbol.nterm Prim.identref)))
                                             ((Pcoq.Symbol.token (Tok.PKEYWORD (")")))))
                             (fun _ id _ _ _ loc -> 
-# 346 "plugins/ssr/ssrvernac.mlg"
+# 347 "plugins/ssr/ssrvernac.mlg"
                                                            id, Locus.InHypValueOnly 
                                                    );
                            Pcoq.Production.make
@@ -710,50 +721,14 @@ let _ = let () =
                                                            ((Pcoq.Symbol.nterm Prim.identref)))
                                            ((Pcoq.Symbol.token (Tok.PKEYWORD (")")))))
                            (fun _ id _ _ _ loc -> 
-# 345 "plugins/ssr/ssrvernac.mlg"
+# 346 "plugins/ssr/ssrvernac.mlg"
                                                           id, Locus.InHypTypeOnly 
                                                   )]))
         in ()
 
 let _ = let () =
-        Pcoq.grammar_extend hloc
-        (Pcoq.Reuse (None, [Pcoq.Production.make
-                            (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.next 
-                                                            (Pcoq.Rule.next 
-                                                            (Pcoq.Rule.next 
-                                                            (Pcoq.Rule.next 
-                                                            (Pcoq.Rule.stop)
-                                                            ((Pcoq.Symbol.token (Tok.PKEYWORD ("in")))))
-                                                            ((Pcoq.Symbol.token (Tok.PKEYWORD ("(")))))
-                                                            ((Pcoq.Symbol.token (Tok.PIDENT (Some
-                                                            ("Value"))))))
-                                                            ((Pcoq.Symbol.token (Tok.PKEYWORD ("of")))))
-                                                            ((Pcoq.Symbol.nterm ident)))
-                                            ((Pcoq.Symbol.token (Tok.PKEYWORD (")")))))
-                            (fun _ id _ _ _ _ loc -> 
-# 356 "plugins/ssr/ssrvernac.mlg"
-      Tacexpr.HypLocation (CAst.make id, Locus.InHypValueOnly) 
-                                                     );
-                           Pcoq.Production.make
-                           (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.next 
-                                                           (Pcoq.Rule.next 
-                                                           (Pcoq.Rule.next 
-                                                           (Pcoq.Rule.next 
-                                                           (Pcoq.Rule.stop)
-                                                           ((Pcoq.Symbol.token (Tok.PKEYWORD ("in")))))
-                                                           ((Pcoq.Symbol.token (Tok.PKEYWORD ("(")))))
-                                                           ((Pcoq.Symbol.token (Tok.PKEYWORD ("Type")))))
-                                                           ((Pcoq.Symbol.token (Tok.PKEYWORD ("of")))))
-                                                           ((Pcoq.Symbol.nterm ident)))
-                                           ((Pcoq.Symbol.token (Tok.PKEYWORD (")")))))
-                           (fun _ id _ _ _ _ loc -> 
-# 354 "plugins/ssr/ssrvernac.mlg"
-      Tacexpr.HypLocation (CAst.make id, Locus.InHypTypeOnly) 
-                                                    )]))
-        in ()
-
-let _ = let () =
-        Pcoq.grammar_extend constr_eval
+        Egramml.grammar_extend ~plugin_uid:("coq-core.plugins.ssreflect", "ssrvernac.mlg:11")
+        constr_eval
         (Pcoq.Reuse (None, [Pcoq.Production.make
                             (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.next 
                                                             (Pcoq.Rule.stop)
@@ -762,16 +737,21 @@ let _ = let () =
                                                             ((Pcoq.Symbol.token (Tok.PKEYWORD ("of")))))
                                             ((Pcoq.Symbol.nterm Constr.constr)))
                             (fun c _ _ loc -> 
-# 363 "plugins/ssr/ssrvernac.mlg"
+# 354 "plugins/ssr/ssrvernac.mlg"
                                                  Genredexpr.ConstrTypeOf c 
                                               )]))
         in ()
 
 
-# 371 "plugins/ssr/ssrvernac.mlg"
+# 358 "plugins/ssr/ssrvernac.mlg"
  
 
-let () = CLexer.set_keyword_state frozen_lexer ;;
+(* We wipe out all the keywords generated by the grammar rules we defined. *)
+(* The user is supposed to Require Import ssreflect or Require ssreflect   *)
+(* and Import ssreflect.SsrSyntax to obtain these keywords and as a         *)
+(* consequence the extended ssreflect grammar.                             *)
+let () = Mltop.add_init_function "coq-core.plugins.ssreflect" (fun () ->
+    Pcoq.set_keyword_state !frozen_lexer) ;;
 
 
 
