@@ -1,5 +1,4 @@
-let __coq_plugin_name = "tuto1_plugin"
-let _ = Mltop.add_known_module __coq_plugin_name
+let _ = Mltop.add_known_module "coq-plugin-tutorial.tuto1"
 
 # 3 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
  
@@ -17,11 +16,11 @@ open Stdarg
 
 
 
-let () = Vernacextend.vernac_extend ~command:"WhatIsThis" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tuto1") ~command:"WhatIsThis" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("What's", 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_constr), 
                                      Vernacextend.TyNil)), (let coqpp_body e
-                                                           () = Vernacextend.VtDefault (fun () -> 
+                                                           () = Vernactypes.vtdefault (fun () -> 
                                                                 
 # 39 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
     
@@ -40,7 +39,7 @@ let () = Vernacextend.vernac_extend ~command:"WhatIsThis" ~classifier:(fun _ ->
                                                                    Vernacextend.TyNonTerminal (
                                                                    Extend.TUentry (Genarg.get_arg_tag wit_string), 
                                                                    Vernacextend.TyNil)))))), 
-         (let coqpp_body s () = Vernacextend.VtDefault (fun () -> 
+         (let coqpp_body s () = Vernactypes.vtdefault (fun () -> 
 # 45 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
      Inspector.print_input s strbrk "string" 
                                 ) in fun s
@@ -53,7 +52,7 @@ let () = Vernacextend.vernac_extend ~command:"WhatIsThis" ~classifier:(fun _ ->
                                                                    Vernacextend.TyNonTerminal (
                                                                    Extend.TUentry (Genarg.get_arg_tag wit_int), 
                                                                    Vernacextend.TyNil)))))), 
-         (let coqpp_body i () = Vernacextend.VtDefault (fun () -> 
+         (let coqpp_body i () = Vernactypes.vtdefault (fun () -> 
 # 47 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
      Inspector.print_input i Pp.int "int" 
                                 ) in fun i
@@ -66,11 +65,10 @@ let () = Vernacextend.vernac_extend ~command:"WhatIsThis" ~classifier:(fun _ ->
                                                                    Vernacextend.TyNonTerminal (
                                                                    Extend.TUentry (Genarg.get_arg_tag wit_ident), 
                                                                    Vernacextend.TyNil)))))), 
-         (let coqpp_body id
-         () = Vernacextend.VtDefault (fun () -> 
+         (let coqpp_body id () = Vernactypes.vtdefault (fun () -> 
 # 49 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
      Inspector.print_input id Ppconstr.pr_id "identifier" 
-              ) in fun id
+                                 ) in fun id
          ?loc ~atts () -> coqpp_body id
          (Attributes.unsupported_attributes atts)), None));
          (Vernacextend.TyML (false, Vernacextend.TyTerminal ("What", 
@@ -80,14 +78,14 @@ let () = Vernacextend.vernac_extend ~command:"WhatIsThis" ~classifier:(fun _ ->
                                                                    Vernacextend.TyNonTerminal (
                                                                    Extend.TUentry (Genarg.get_arg_tag wit_reference), 
                                                                    Vernacextend.TyNil)))))), 
-         (let coqpp_body r () = Vernacextend.VtDefault (fun () -> 
+         (let coqpp_body r () = Vernactypes.vtdefault (fun () -> 
 # 51 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
      Inspector.print_input r Ppconstr.pr_qualid "reference" 
                                 ) in fun r
          ?loc ~atts () -> coqpp_body r
          (Attributes.unsupported_attributes atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"WhatAreThese" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tuto1") ~command:"WhatAreThese" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("What", 
                                      Vernacextend.TyTerminal ("is", Vernacextend.TyNonTerminal (
                                                                     Extend.TUlist0 (
@@ -96,7 +94,7 @@ let () = Vernacextend.vernac_extend ~command:"WhatAreThese" ~classifier:(fun _ -
                                                                     Vernacextend.TyTerminal ("list", 
                                                                     Vernacextend.TyTerminal ("of", 
                                                                     Vernacextend.TyNil)))))), 
-         (let coqpp_body l () = Vernacextend.VtDefault (fun () -> 
+         (let coqpp_body l () = Vernactypes.vtdefault (fun () -> 
 # 60 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
     
      let print l = str "[" ++ Pp.prlist_with_sep (fun () -> str ";") Pp.int l ++ str "]" in
@@ -110,7 +108,7 @@ let () = Vernacextend.vernac_extend ~command:"WhatAreThese" ~classifier:(fun _ -
                                                                    Extend.TUentry (Genarg.get_arg_tag wit_int)), 
                                                                    Vernacextend.TyTerminal ("nonempty", 
                                                                    Vernacextend.TyNil))), 
-         (let coqpp_body l () = Vernacextend.VtDefault (fun () -> 
+         (let coqpp_body l () = Vernactypes.vtdefault (fun () -> 
 # 65 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
     
      let print l = str "[" ++ Pp.prlist_with_sep (fun () -> str ";") Pp.int l ++ str "]" in
@@ -125,7 +123,7 @@ let () = Vernacextend.vernac_extend ~command:"WhatAreThese" ~classifier:(fun _ -
                                                                     Extend.TUentry (Genarg.get_arg_tag wit_int)), 
                                                                     Vernacextend.TyTerminal ("provided", 
                                                                     Vernacextend.TyNil)))), 
-         (let coqpp_body o () = Vernacextend.VtDefault (fun () -> 
+         (let coqpp_body o () = Vernactypes.vtdefault (fun () -> 
 # 70 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
     
      let print o = strbrk (if Option.has_some o then "Yes" else "No") in
@@ -135,11 +133,11 @@ let () = Vernacextend.vernac_extend ~command:"WhatAreThese" ~classifier:(fun _ -
          ?loc ~atts () -> coqpp_body o
          (Attributes.unsupported_attributes atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"Intern" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tuto1") ~command:"Intern" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Intern", 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_constr), 
                                      Vernacextend.TyNil)), (let coqpp_body e
-                                                           () = Vernacextend.VtDefault (fun () -> 
+                                                           () = Vernactypes.vtdefault (fun () -> 
                                                                 
 # 116 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
     
@@ -157,14 +155,14 @@ let () = Vernacextend.vernac_extend ~command:"Intern" ~classifier:(fun _ -> Vern
                                                            -> coqpp_body e
                                                            (Attributes.unsupported_attributes atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"MyDefine" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tuto1") ~command:"MyDefine" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("MyDefine", 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_ident), 
                                      Vernacextend.TyTerminal (":=", Vernacextend.TyNonTerminal (
                                                                     Extend.TUentry (Genarg.get_arg_tag wit_constr), 
                                                                     Vernacextend.TyNil)))), 
          (let coqpp_body i e
-         poly = Vernacextend.VtDefault (fun () -> 
+         poly = Vernactypes.vtdefault (fun () -> 
 # 151 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
     
      let env = Global.env () in
@@ -178,11 +176,11 @@ let () = Vernacextend.vernac_extend ~command:"MyDefine" ~classifier:(fun _ -> Ve
          e ?loc ~atts () -> coqpp_body i e
          (Attributes.parse Attributes.polymorphic atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"ExamplePrint" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tuto1") ~command:"ExamplePrint" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("MyPrint", 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_reference), 
                                      Vernacextend.TyNil)), (let coqpp_body r
-                                                           () = Vernacextend.VtDefault (fun () -> 
+                                                           () = Vernactypes.vtdefault (fun () -> 
                                                                 
 # 173 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
     
@@ -199,14 +197,14 @@ let () = Vernacextend.vernac_extend ~command:"ExamplePrint" ~classifier:(fun _ -
                                                            -> coqpp_body r
                                                            (Attributes.unsupported_attributes atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"DefineLookup" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tuto1") ~command:"DefineLookup" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("DefineLookup", 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_ident), 
                                      Vernacextend.TyTerminal (":=", Vernacextend.TyNonTerminal (
                                                                     Extend.TUentry (Genarg.get_arg_tag wit_constr), 
                                                                     Vernacextend.TyNil)))), 
          (let coqpp_body i e
-         poly = Vernacextend.VtDefault (fun () -> 
+         poly = Vernactypes.vtdefault (fun () -> 
 # 199 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
     
      let env = Global.env () in
@@ -225,11 +223,11 @@ let () = Vernacextend.vernac_extend ~command:"DefineLookup" ~classifier:(fun _ -
          e ?loc ~atts () -> coqpp_body i e
          (Attributes.parse Attributes.polymorphic atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"Check1" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tuto1") ~command:"Check1" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Check1", 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_constr), 
                                      Vernacextend.TyNil)), (let coqpp_body e
-                                                           () = Vernacextend.VtDefault (fun () -> 
+                                                           () = Vernactypes.vtdefault (fun () -> 
                                                                 
 # 223 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
     
@@ -244,11 +242,11 @@ let () = Vernacextend.vernac_extend ~command:"Check1" ~classifier:(fun _ -> Vern
                                                            -> coqpp_body e
                                                            (Attributes.unsupported_attributes atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"Check2" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tuto1") ~command:"Check2" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Check2", 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_constr), 
                                      Vernacextend.TyNil)), (let coqpp_body e
-                                                           () = Vernacextend.VtDefault (fun () -> 
+                                                           () = Vernactypes.vtdefault (fun () -> 
                                                                 
 # 234 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
     
@@ -263,13 +261,13 @@ let () = Vernacextend.vernac_extend ~command:"Check2" ~classifier:(fun _ -> Vern
                                                            -> coqpp_body e
                                                            (Attributes.unsupported_attributes atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"Convertible" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tuto1") ~command:"Convertible" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Convertible", 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_constr), 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_constr), 
                                      Vernacextend.TyNil))), (let coqpp_body e1
                                                             e2
-                                                            () = Vernacextend.VtDefault (fun () -> 
+                                                            () = Vernactypes.vtdefault (fun () -> 
                                                                  
 # 252 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
     
@@ -289,7 +287,7 @@ let () = Vernacextend.vernac_extend ~command:"Convertible" ~classifier:(fun _ ->
                                                             e2
                                                             (Attributes.unsupported_attributes atts)), None))]
 
-let () = Tacentries.tactic_extend __coq_plugin_name "my_intro" ~level:0 
+let () = Tacentries.tactic_extend "coq-plugin-tutorial.tuto1" "my_intro" ~level:0 
          [(Tacentries.TyML (Tacentries.TyIdent ("my_intro", Tacentries.TyArg (
                                                             Extend.TUentry (Genarg.get_arg_tag wit_ident), 
                                                             Tacentries.TyNil)), 
@@ -298,10 +296,10 @@ let () = Tacentries.tactic_extend __coq_plugin_name "my_intro" ~level:0
     Tactics.introduction i 
            )))]
 
-let () = Vernacextend.vernac_extend ~command:"ExploreProof" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tuto1") ~command:"ExploreProof" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("ExploreProof", 
                                      Vernacextend.TyNil), (let coqpp_body () = 
-                                                          Vernacextend.VtReadProof (
+                                                          Vernactypes.vtreadproof (fun ~pstate -> (
                                                           
 # 288 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
     fun ~pstate ->
@@ -310,6 +308,6 @@ let () = Vernacextend.vernac_extend ~command:"ExploreProof" ~classifier:(fun _ -
     Feedback.msg_notice
       (Pp.prlist_with_sep Pp.fnl (Printer.pr_econstr_env env sigma) pprf)
   
-                                                          ) in fun ?loc ~atts ()
+                                                          ) ~pstate) in fun ?loc ~atts ()
                                                           -> coqpp_body (Attributes.unsupported_attributes atts)), None))]
 
